/********************************************************************************
** Form generated from reading UI file 'track_type_page.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TRACK_TYPE_PAGE_H
#define TRACK_TYPE_PAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {
namespace HeaderEditor {

class Ui_TrackTypePage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *m_lTitle;
    QFrame *line;
    QGridLayout *gridLayout;
    QLabel *m_lTrackNumberMkvpropeditLabel;
    QLabel *m_lTypeLabel;
    QLabel *m_lType;
    QLabel *m_lCodecIdLabel;
    QLabel *m_lCodecId;
    QLabel *m_lTrackIdxMkvmergeLabel;
    QLabel *m_lTrackIdxMkvmerge;
    QLabel *m_lTrackNumberMkvpropedit;
    QLabel *m_lUidLabel;
    QLabel *m_lUid;
    QLabel *m_lLanguageLabel;
    QLabel *m_lLanguage;
    QLabel *m_lNameLabel;
    QLabel *m_lName;
    QLabel *m_lDefaultTrackFlagLabel;
    QHBoxLayout *horizontalLayout;
    QLabel *m_iDefaultTrackFlag;
    QLabel *m_lDefaultTrackFlag;
    QLabel *m_lForcedTrackFlagLabel;
    QHBoxLayout *horizontalLayout_2;
    QLabel *m_iForcedTrackFlag;
    QLabel *m_lForcedTrackFlag;
    QLabel *m_lEnabledTrackFlagLabel;
    QHBoxLayout *horizontalLayout_3;
    QLabel *m_iEnabledTrackFlag;
    QLabel *m_lEnabledTrackFlag;
    QLabel *m_lPropertiesLabel;
    QLabel *m_lProperties;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *mtx__gui__HeaderEditor__TrackTypePage)
    {
        if (mtx__gui__HeaderEditor__TrackTypePage->objectName().isEmpty())
            mtx__gui__HeaderEditor__TrackTypePage->setObjectName("mtx__gui__HeaderEditor__TrackTypePage");
        mtx__gui__HeaderEditor__TrackTypePage->resize(504, 489);
        mtx__gui__HeaderEditor__TrackTypePage->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(mtx__gui__HeaderEditor__TrackTypePage);
        verticalLayout->setObjectName("verticalLayout");
        m_lTitle = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lTitle->setObjectName("m_lTitle");
        m_lTitle->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(m_lTitle);

        line = new QFrame(mtx__gui__HeaderEditor__TrackTypePage);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        m_lTrackNumberMkvpropeditLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lTrackNumberMkvpropeditLabel->setObjectName("m_lTrackNumberMkvpropeditLabel");

        gridLayout->addWidget(m_lTrackNumberMkvpropeditLabel, 3, 0, 1, 1);

        m_lTypeLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lTypeLabel->setObjectName("m_lTypeLabel");

        gridLayout->addWidget(m_lTypeLabel, 0, 0, 1, 1);

        m_lType = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lType->setObjectName("m_lType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_lType->sizePolicy().hasHeightForWidth());
        m_lType->setSizePolicy(sizePolicy);
        m_lType->setText(QString::fromUtf8("TextLabel"));
        m_lType->setTextFormat(Qt::PlainText);
        m_lType->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lType, 0, 1, 1, 1);

        m_lCodecIdLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lCodecIdLabel->setObjectName("m_lCodecIdLabel");

        gridLayout->addWidget(m_lCodecIdLabel, 1, 0, 1, 1);

        m_lCodecId = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lCodecId->setObjectName("m_lCodecId");
        sizePolicy.setHeightForWidth(m_lCodecId->sizePolicy().hasHeightForWidth());
        m_lCodecId->setSizePolicy(sizePolicy);
        m_lCodecId->setText(QString::fromUtf8("TextLabel"));
        m_lCodecId->setTextFormat(Qt::PlainText);
        m_lCodecId->setWordWrap(true);
        m_lCodecId->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lCodecId, 1, 1, 1, 1);

        m_lTrackIdxMkvmergeLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lTrackIdxMkvmergeLabel->setObjectName("m_lTrackIdxMkvmergeLabel");

        gridLayout->addWidget(m_lTrackIdxMkvmergeLabel, 2, 0, 1, 1);

        m_lTrackIdxMkvmerge = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lTrackIdxMkvmerge->setObjectName("m_lTrackIdxMkvmerge");
        sizePolicy.setHeightForWidth(m_lTrackIdxMkvmerge->sizePolicy().hasHeightForWidth());
        m_lTrackIdxMkvmerge->setSizePolicy(sizePolicy);
        m_lTrackIdxMkvmerge->setText(QString::fromUtf8("TextLabel"));
        m_lTrackIdxMkvmerge->setTextFormat(Qt::PlainText);
        m_lTrackIdxMkvmerge->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lTrackIdxMkvmerge, 2, 1, 1, 1);

        m_lTrackNumberMkvpropedit = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lTrackNumberMkvpropedit->setObjectName("m_lTrackNumberMkvpropedit");
        sizePolicy.setHeightForWidth(m_lTrackNumberMkvpropedit->sizePolicy().hasHeightForWidth());
        m_lTrackNumberMkvpropedit->setSizePolicy(sizePolicy);
        m_lTrackNumberMkvpropedit->setText(QString::fromUtf8("TextLabel"));
        m_lTrackNumberMkvpropedit->setTextFormat(Qt::PlainText);
        m_lTrackNumberMkvpropedit->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lTrackNumberMkvpropedit, 3, 1, 1, 1);

        m_lUidLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lUidLabel->setObjectName("m_lUidLabel");

        gridLayout->addWidget(m_lUidLabel, 4, 0, 1, 1);

        m_lUid = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lUid->setObjectName("m_lUid");
        sizePolicy.setHeightForWidth(m_lUid->sizePolicy().hasHeightForWidth());
        m_lUid->setSizePolicy(sizePolicy);
        m_lUid->setText(QString::fromUtf8("TextLabel"));
        m_lUid->setTextFormat(Qt::PlainText);
        m_lUid->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lUid, 4, 1, 1, 1);

        m_lLanguageLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lLanguageLabel->setObjectName("m_lLanguageLabel");

        gridLayout->addWidget(m_lLanguageLabel, 5, 0, 1, 1);

        m_lLanguage = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lLanguage->setObjectName("m_lLanguage");
        sizePolicy.setHeightForWidth(m_lLanguage->sizePolicy().hasHeightForWidth());
        m_lLanguage->setSizePolicy(sizePolicy);
        m_lLanguage->setText(QString::fromUtf8("TextLabel"));
        m_lLanguage->setTextFormat(Qt::PlainText);
        m_lLanguage->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lLanguage, 5, 1, 1, 1);

        m_lNameLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lNameLabel->setObjectName("m_lNameLabel");

        gridLayout->addWidget(m_lNameLabel, 6, 0, 1, 1);

        m_lName = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lName->setObjectName("m_lName");
        sizePolicy.setHeightForWidth(m_lName->sizePolicy().hasHeightForWidth());
        m_lName->setSizePolicy(sizePolicy);
        m_lName->setText(QString::fromUtf8("TextLabel"));
        m_lName->setTextFormat(Qt::PlainText);
        m_lName->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lName, 6, 1, 1, 1);

        m_lDefaultTrackFlagLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lDefaultTrackFlagLabel->setObjectName("m_lDefaultTrackFlagLabel");

        gridLayout->addWidget(m_lDefaultTrackFlagLabel, 7, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_iDefaultTrackFlag = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_iDefaultTrackFlag->setObjectName("m_iDefaultTrackFlag");
        m_iDefaultTrackFlag->setText(QString::fromUtf8("icon"));

        horizontalLayout->addWidget(m_iDefaultTrackFlag);

        m_lDefaultTrackFlag = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lDefaultTrackFlag->setObjectName("m_lDefaultTrackFlag");
        sizePolicy.setHeightForWidth(m_lDefaultTrackFlag->sizePolicy().hasHeightForWidth());
        m_lDefaultTrackFlag->setSizePolicy(sizePolicy);
        m_lDefaultTrackFlag->setText(QString::fromUtf8("TextLabel"));
        m_lDefaultTrackFlag->setTextFormat(Qt::PlainText);
        m_lDefaultTrackFlag->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout->addWidget(m_lDefaultTrackFlag);


        gridLayout->addLayout(horizontalLayout, 7, 1, 1, 1);

        m_lForcedTrackFlagLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lForcedTrackFlagLabel->setObjectName("m_lForcedTrackFlagLabel");

        gridLayout->addWidget(m_lForcedTrackFlagLabel, 8, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_iForcedTrackFlag = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_iForcedTrackFlag->setObjectName("m_iForcedTrackFlag");
        m_iForcedTrackFlag->setText(QString::fromUtf8("icon"));

        horizontalLayout_2->addWidget(m_iForcedTrackFlag);

        m_lForcedTrackFlag = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lForcedTrackFlag->setObjectName("m_lForcedTrackFlag");
        sizePolicy.setHeightForWidth(m_lForcedTrackFlag->sizePolicy().hasHeightForWidth());
        m_lForcedTrackFlag->setSizePolicy(sizePolicy);
        m_lForcedTrackFlag->setText(QString::fromUtf8("TextLabel"));
        m_lForcedTrackFlag->setTextFormat(Qt::PlainText);
        m_lForcedTrackFlag->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(m_lForcedTrackFlag);


        gridLayout->addLayout(horizontalLayout_2, 8, 1, 1, 1);

        m_lEnabledTrackFlagLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lEnabledTrackFlagLabel->setObjectName("m_lEnabledTrackFlagLabel");

        gridLayout->addWidget(m_lEnabledTrackFlagLabel, 9, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_iEnabledTrackFlag = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_iEnabledTrackFlag->setObjectName("m_iEnabledTrackFlag");
        m_iEnabledTrackFlag->setText(QString::fromUtf8("icon"));

        horizontalLayout_3->addWidget(m_iEnabledTrackFlag);

        m_lEnabledTrackFlag = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lEnabledTrackFlag->setObjectName("m_lEnabledTrackFlag");
        sizePolicy.setHeightForWidth(m_lEnabledTrackFlag->sizePolicy().hasHeightForWidth());
        m_lEnabledTrackFlag->setSizePolicy(sizePolicy);
        m_lEnabledTrackFlag->setText(QString::fromUtf8("TextLabel"));
        m_lEnabledTrackFlag->setTextFormat(Qt::PlainText);
        m_lEnabledTrackFlag->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout_3->addWidget(m_lEnabledTrackFlag);


        gridLayout->addLayout(horizontalLayout_3, 9, 1, 1, 1);

        m_lPropertiesLabel = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lPropertiesLabel->setObjectName("m_lPropertiesLabel");

        gridLayout->addWidget(m_lPropertiesLabel, 10, 0, 1, 1);

        m_lProperties = new QLabel(mtx__gui__HeaderEditor__TrackTypePage);
        m_lProperties->setObjectName("m_lProperties");
        sizePolicy.setHeightForWidth(m_lProperties->sizePolicy().hasHeightForWidth());
        m_lProperties->setSizePolicy(sizePolicy);
        m_lProperties->setText(QString::fromUtf8("TextLabel"));
        m_lProperties->setTextFormat(Qt::PlainText);
        m_lProperties->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(m_lProperties, 10, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 357, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(mtx__gui__HeaderEditor__TrackTypePage);

        QMetaObject::connectSlotsByName(mtx__gui__HeaderEditor__TrackTypePage);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__HeaderEditor__TrackTypePage)
    {
        m_lTrackNumberMkvpropeditLabel->setText(QTR("Track number for mkvpropedit:", nullptr));
        m_lTypeLabel->setText(QTR("Type:", nullptr));
        m_lCodecIdLabel->setText(QTR("Codec ID:", nullptr));
        m_lTrackIdxMkvmergeLabel->setText(QTR("Track ID for mkvmerge & mkvextract:", nullptr));
        m_lUidLabel->setText(QTR("UID:", nullptr));
        m_lLanguageLabel->setText(QTR("Language:", nullptr));
        m_lNameLabel->setText(QTR("Name:", nullptr));
        m_lDefaultTrackFlagLabel->setText(QTR("\"Default track\" flag:", nullptr));
        m_lForcedTrackFlagLabel->setText(QTR("\"Forced display\" flag:", nullptr));
        m_lEnabledTrackFlagLabel->setText(QTR("\"Track enabled\" flag:", nullptr));
        m_lPropertiesLabel->setText(QTR("Properties:", nullptr));
        (void)mtx__gui__HeaderEditor__TrackTypePage;
    } // retranslateUi

};

} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace HeaderEditor {
namespace Ui {
    class TrackTypePage: public Ui_TrackTypePage {};
} // namespace Ui
} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

#endif // TRACK_TYPE_PAGE_H
