/********************************************************************************
** Form generated from reading UI file 'ask_scan_for_playlists_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ASK_SCAN_FOR_PLAYLISTS_DIALOG_H
#define ASK_SCAN_FOR_PLAYLISTS_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace Merge {

class Ui_AskScanForPlaylistsDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *iconLabel;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout_2;
    QLabel *questionLabel;
    QHBoxLayout *horizontalLayout;
    QLabel *inTheFutureLabel;
    QComboBox *scanPolicy;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__Merge__AskScanForPlaylistsDialog)
    {
        if (mtx__gui__Merge__AskScanForPlaylistsDialog->objectName().isEmpty())
            mtx__gui__Merge__AskScanForPlaylistsDialog->setObjectName("mtx__gui__Merge__AskScanForPlaylistsDialog");
        mtx__gui__Merge__AskScanForPlaylistsDialog->setWindowModality(Qt::WindowModal);
        mtx__gui__Merge__AskScanForPlaylistsDialog->resize(551, 122);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mtx__gui__Merge__AskScanForPlaylistsDialog->sizePolicy().hasHeightForWidth());
        mtx__gui__Merge__AskScanForPlaylistsDialog->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(mtx__gui__Merge__AskScanForPlaylistsDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(10, -1, 10, -1);
        iconLabel = new QLabel(mtx__gui__Merge__AskScanForPlaylistsDialog);
        iconLabel->setObjectName("iconLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy1);
        iconLabel->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(iconLabel);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        questionLabel = new QLabel(mtx__gui__Merge__AskScanForPlaylistsDialog);
        questionLabel->setObjectName("questionLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(questionLabel->sizePolicy().hasHeightForWidth());
        questionLabel->setSizePolicy(sizePolicy2);
        questionLabel->setText(QString::fromUtf8("dummy"));
        questionLabel->setWordWrap(true);
        questionLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        verticalLayout_2->addWidget(questionLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        inTheFutureLabel = new QLabel(mtx__gui__Merge__AskScanForPlaylistsDialog);
        inTheFutureLabel->setObjectName("inTheFutureLabel");
        sizePolicy.setHeightForWidth(inTheFutureLabel->sizePolicy().hasHeightForWidth());
        inTheFutureLabel->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(inTheFutureLabel);

        scanPolicy = new QComboBox(mtx__gui__Merge__AskScanForPlaylistsDialog);
        scanPolicy->addItem(QString());
        scanPolicy->addItem(QString());
        scanPolicy->addItem(QString());
        scanPolicy->setObjectName("scanPolicy");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(scanPolicy->sizePolicy().hasHeightForWidth());
        scanPolicy->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(scanPolicy);


        verticalLayout_2->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(mtx__gui__Merge__AskScanForPlaylistsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::No|QDialogButtonBox::Yes);

        verticalLayout_3->addWidget(buttonBox);

        QWidget::setTabOrder(scanPolicy, buttonBox);

        retranslateUi(mtx__gui__Merge__AskScanForPlaylistsDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Merge__AskScanForPlaylistsDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__AskScanForPlaylistsDialog)
    {
        mtx__gui__Merge__AskScanForPlaylistsDialog->setWindowTitle(QTR("Scan directory for other playlists", nullptr));
        inTheFutureLabel->setText(QTR("What to do in the future:", nullptr));
        scanPolicy->setItemText(0, QTR("Always ask the user", nullptr));
        scanPolicy->setItemText(1, QTR("Always scan for other playlists", nullptr));
        scanPolicy->setItemText(2, QTR("Never scan for other playlists", nullptr));

    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class AskScanForPlaylistsDialog: public Ui_AskScanForPlaylistsDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // ASK_SCAN_FOR_PLAYLISTS_DIALOG_H
