/********************************************************************************
** Form generated from reading UI file 'language_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef LANGUAGE_DIALOG_H
#define LANGUAGE_DIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/country_combo_box.h"
#include "mkvtoolnix-gui/util/language_combo_box.h"

namespace mtx {
namespace gui {
namespace Util {

class Ui_LanguageDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *rbFreeForm;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLineEdit *leFreeForm;
    QRadioButton *rbComponentSelection;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QScrollArea *saComponents;
    QWidget *sawComponents;
    QGridLayout *sawComponentsLayout;
    QComboBox *cbScript;
    QLabel *lRegion;
    QLabel *lLanguage;
    mtx::gui::Util::LanguageComboBox *cbLanguage;
    QSpacerItem *verticalSpacer_2;
    QComboBox *cbVariant1;
    QLabel *lVariants;
    mtx::gui::Util::CountryComboBox *cbRegion;
    QLabel *lPrivateUse;
    QPushButton *pbAddVariant;
    QLabel *lExtendedSubtag;
    QComboBox *cbExtendedSubtag;
    QLineEdit *lePrivateUse1;
    QPushButton *pbAddPrivateUse;
    QLabel *lScript;
    QLabel *lExtensions;
    QLineEdit *leExtension1;
    QPushButton *pbAddExtension;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *lInfoWarningsLabel;
    QLabel *lStatusLabel;
    QWidget *wInfoWarnings;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lStatusOKIcon;
    QLabel *lStatusBadIcon;
    QLabel *lStatusText;
    QLabel *lParserErrorLabel;
    QLabel *lParserError;
    QHBoxLayout *horizontalLayout_4;
    QToolButton *tbReplaceNormalized;
    QSpacerItem *horizontalSpacer_3;
    QDialogButtonBox *bbOkCancel;

    void setupUi(QDialog *mtx__gui__Util__LanguageDialog)
    {
        if (mtx__gui__Util__LanguageDialog->objectName().isEmpty())
            mtx__gui__Util__LanguageDialog->setObjectName("mtx__gui__Util__LanguageDialog");
        mtx__gui__Util__LanguageDialog->resize(801, 537);
        verticalLayout_2 = new QVBoxLayout(mtx__gui__Util__LanguageDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(mtx__gui__Util__LanguageDialog);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        rbFreeForm = new QRadioButton(groupBox);
        rbFreeForm->setObjectName("rbFreeForm");

        verticalLayout->addWidget(rbFreeForm);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(24, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        leFreeForm = new QLineEdit(groupBox);
        leFreeForm->setObjectName("leFreeForm");

        horizontalLayout->addWidget(leFreeForm);


        verticalLayout->addLayout(horizontalLayout);

        rbComponentSelection = new QRadioButton(groupBox);
        rbComponentSelection->setObjectName("rbComponentSelection");

        verticalLayout->addWidget(rbComponentSelection);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(24, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        saComponents = new QScrollArea(groupBox);
        saComponents->setObjectName("saComponents");
        saComponents->setFrameShape(QFrame::NoFrame);
        saComponents->setFrameShadow(QFrame::Plain);
        saComponents->setWidgetResizable(true);
        saComponents->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        sawComponents = new QWidget();
        sawComponents->setObjectName("sawComponents");
        sawComponents->setGeometry(QRect(0, 0, 733, 225));
        sawComponents->setAutoFillBackground(true);
        sawComponentsLayout = new QGridLayout(sawComponents);
        sawComponentsLayout->setObjectName("sawComponentsLayout");
        sawComponentsLayout->setContentsMargins(0, 0, 0, 0);
        cbScript = new QComboBox(sawComponents);
        cbScript->setObjectName("cbScript");

        sawComponentsLayout->addWidget(cbScript, 2, 1, 1, 1);

        lRegion = new QLabel(sawComponents);
        lRegion->setObjectName("lRegion");

        sawComponentsLayout->addWidget(lRegion, 3, 0, 1, 1);

        lLanguage = new QLabel(sawComponents);
        lLanguage->setObjectName("lLanguage");

        sawComponentsLayout->addWidget(lLanguage, 0, 0, 1, 1);

        cbLanguage = new mtx::gui::Util::LanguageComboBox(sawComponents);
        cbLanguage->setObjectName("cbLanguage");

        sawComponentsLayout->addWidget(cbLanguage, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        sawComponentsLayout->addItem(verticalSpacer_2, 7, 1, 1, 1);

        cbVariant1 = new QComboBox(sawComponents);
        cbVariant1->setObjectName("cbVariant1");

        sawComponentsLayout->addWidget(cbVariant1, 4, 1, 1, 1);

        lVariants = new QLabel(sawComponents);
        lVariants->setObjectName("lVariants");

        sawComponentsLayout->addWidget(lVariants, 4, 0, 1, 1);

        cbRegion = new mtx::gui::Util::CountryComboBox(sawComponents);
        cbRegion->setObjectName("cbRegion");

        sawComponentsLayout->addWidget(cbRegion, 3, 1, 1, 1);

        lPrivateUse = new QLabel(sawComponents);
        lPrivateUse->setObjectName("lPrivateUse");

        sawComponentsLayout->addWidget(lPrivateUse, 6, 0, 1, 1);

        pbAddVariant = new QPushButton(sawComponents);
        pbAddVariant->setObjectName("pbAddVariant");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        pbAddVariant->setIcon(icon);

        sawComponentsLayout->addWidget(pbAddVariant, 4, 2, 1, 1);

        lExtendedSubtag = new QLabel(sawComponents);
        lExtendedSubtag->setObjectName("lExtendedSubtag");

        sawComponentsLayout->addWidget(lExtendedSubtag, 1, 0, 1, 1);

        cbExtendedSubtag = new QComboBox(sawComponents);
        cbExtendedSubtag->setObjectName("cbExtendedSubtag");

        sawComponentsLayout->addWidget(cbExtendedSubtag, 1, 1, 1, 1);

        lePrivateUse1 = new QLineEdit(sawComponents);
        lePrivateUse1->setObjectName("lePrivateUse1");

        sawComponentsLayout->addWidget(lePrivateUse1, 6, 1, 1, 1);

        pbAddPrivateUse = new QPushButton(sawComponents);
        pbAddPrivateUse->setObjectName("pbAddPrivateUse");
        pbAddPrivateUse->setIcon(icon);

        sawComponentsLayout->addWidget(pbAddPrivateUse, 6, 2, 1, 1);

        lScript = new QLabel(sawComponents);
        lScript->setObjectName("lScript");

        sawComponentsLayout->addWidget(lScript, 2, 0, 1, 1);

        lExtensions = new QLabel(sawComponents);
        lExtensions->setObjectName("lExtensions");

        sawComponentsLayout->addWidget(lExtensions, 5, 0, 1, 1);

        leExtension1 = new QLineEdit(sawComponents);
        leExtension1->setObjectName("leExtension1");

        sawComponentsLayout->addWidget(leExtension1, 5, 1, 1, 1);

        pbAddExtension = new QPushButton(sawComponents);
        pbAddExtension->setObjectName("pbAddExtension");
        pbAddExtension->setText(QString::fromUtf8(""));
        pbAddExtension->setIcon(icon);

        sawComponentsLayout->addWidget(pbAddExtension, 5, 2, 1, 1);

        saComponents->setWidget(sawComponents);

        horizontalLayout_2->addWidget(saComponents);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(mtx__gui__Util__LanguageDialog);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        lInfoWarningsLabel = new QLabel(groupBox_2);
        lInfoWarningsLabel->setObjectName("lInfoWarningsLabel");
        lInfoWarningsLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout->addWidget(lInfoWarningsLabel, 2, 0, 1, 1);

        lStatusLabel = new QLabel(groupBox_2);
        lStatusLabel->setObjectName("lStatusLabel");

        gridLayout->addWidget(lStatusLabel, 0, 0, 1, 1);

        wInfoWarnings = new QWidget(groupBox_2);
        wInfoWarnings->setObjectName("wInfoWarnings");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(wInfoWarnings->sizePolicy().hasHeightForWidth());
        wInfoWarnings->setSizePolicy(sizePolicy);

        gridLayout->addWidget(wInfoWarnings, 2, 1, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lStatusOKIcon = new QLabel(groupBox_2);
        lStatusOKIcon->setObjectName("lStatusOKIcon");
        lStatusOKIcon->setMaximumSize(QSize(16, 16));
        lStatusOKIcon->setText(QString::fromUtf8(""));
        lStatusOKIcon->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/small/16x16/dialog-ok-apply.svg")));
        lStatusOKIcon->setScaledContents(true);

        horizontalLayout_3->addWidget(lStatusOKIcon);

        lStatusBadIcon = new QLabel(groupBox_2);
        lStatusBadIcon->setObjectName("lStatusBadIcon");
        lStatusBadIcon->setMaximumSize(QSize(16, 16));
        lStatusBadIcon->setText(QString::fromUtf8(""));
        lStatusBadIcon->setPixmap(QPixmap(QString::fromUtf8(":/icons/mkvtoolnix-gui/oxygen/small/16x16/dialog-error.svg")));
        lStatusBadIcon->setScaledContents(true);

        horizontalLayout_3->addWidget(lStatusBadIcon);

        lStatusText = new QLabel(groupBox_2);
        lStatusText->setObjectName("lStatusText");
        sizePolicy.setHeightForWidth(lStatusText->sizePolicy().hasHeightForWidth());
        lStatusText->setSizePolicy(sizePolicy);
        lStatusText->setText(QString::fromUtf8("TextLabel"));
        lStatusText->setWordWrap(true);

        horizontalLayout_3->addWidget(lStatusText);


        gridLayout->addLayout(horizontalLayout_3, 0, 1, 1, 1);

        lParserErrorLabel = new QLabel(groupBox_2);
        lParserErrorLabel->setObjectName("lParserErrorLabel");

        gridLayout->addWidget(lParserErrorLabel, 1, 0, 1, 1);

        lParserError = new QLabel(groupBox_2);
        lParserError->setObjectName("lParserError");
        sizePolicy.setHeightForWidth(lParserError->sizePolicy().hasHeightForWidth());
        lParserError->setSizePolicy(sizePolicy);
        lParserError->setText(QString::fromUtf8("actual error text"));
        lParserError->setTextFormat(Qt::PlainText);
        lParserError->setWordWrap(true);

        gridLayout->addWidget(lParserError, 1, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox_2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        tbReplaceNormalized = new QToolButton(mtx__gui__Util__LanguageDialog);
        tbReplaceNormalized->setObjectName("tbReplaceNormalized");
        tbReplaceNormalized->setPopupMode(QToolButton::InstantPopup);

        horizontalLayout_4->addWidget(tbReplaceNormalized);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        bbOkCancel = new QDialogButtonBox(mtx__gui__Util__LanguageDialog);
        bbOkCancel->setObjectName("bbOkCancel");
        bbOkCancel->setOrientation(Qt::Horizontal);
        bbOkCancel->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_4->addWidget(bbOkCancel);


        verticalLayout_2->addLayout(horizontalLayout_4);

#if QT_CONFIG(shortcut)
        lRegion->setBuddy(cbRegion);
        lLanguage->setBuddy(cbLanguage);
        lVariants->setBuddy(cbVariant1);
        lPrivateUse->setBuddy(lePrivateUse1);
        lExtendedSubtag->setBuddy(cbExtendedSubtag);
        lScript->setBuddy(cbScript);
        lExtensions->setBuddy(leExtension1);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(rbFreeForm, leFreeForm);
        QWidget::setTabOrder(leFreeForm, rbComponentSelection);
        QWidget::setTabOrder(rbComponentSelection, saComponents);
        QWidget::setTabOrder(saComponents, cbLanguage);
        QWidget::setTabOrder(cbLanguage, cbExtendedSubtag);
        QWidget::setTabOrder(cbExtendedSubtag, cbScript);
        QWidget::setTabOrder(cbScript, cbRegion);
        QWidget::setTabOrder(cbRegion, cbVariant1);
        QWidget::setTabOrder(cbVariant1, pbAddVariant);
        QWidget::setTabOrder(pbAddVariant, leExtension1);
        QWidget::setTabOrder(leExtension1, pbAddExtension);
        QWidget::setTabOrder(pbAddExtension, lePrivateUse1);
        QWidget::setTabOrder(lePrivateUse1, pbAddPrivateUse);
        QWidget::setTabOrder(pbAddPrivateUse, tbReplaceNormalized);
        QWidget::setTabOrder(tbReplaceNormalized, bbOkCancel);

        retranslateUi(mtx__gui__Util__LanguageDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Util__LanguageDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Util__LanguageDialog)
    {
        mtx__gui__Util__LanguageDialog->setWindowTitle(QTR("Edit language", nullptr));
        groupBox->setTitle(QTR("Edit language", nullptr));
        rbFreeForm->setText(QTR("&Free-form input", nullptr));
        rbComponentSelection->setText(QTR("&Individually selected components", nullptr));
        lRegion->setText(QTR("&Region:", nullptr));
        lLanguage->setText(QTR("&Language:", nullptr));
        lVariants->setText(QTR("&Variants:", nullptr));
        lPrivateUse->setText(QTR("&Private use:", nullptr));
        pbAddVariant->setText(QString());
        lExtendedSubtag->setText(QTR("&Extended language subtag:", nullptr));
        pbAddPrivateUse->setText(QString());
        lScript->setText(QTR("&Script:", nullptr));
        lExtensions->setText(QTR("E&xtensions:", nullptr));
        groupBox_2->setTitle(QTR("Status", nullptr));
        lInfoWarningsLabel->setText(QTR("Information & Warnings:", nullptr));
        lStatusLabel->setText(QTR("Status:", nullptr));
        lParserErrorLabel->setText(QTR("Parser error:", nullptr));
        tbReplaceNormalized->setText(QTR("&Replace with normalized form", nullptr));
    } // retranslateUi

};

} // namespace Util
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Util {
namespace Ui {
    class LanguageDialog: public Ui_LanguageDialog {};
} // namespace Ui
} // namespace Util
} // namespace gui
} // namespace mtx

#endif // LANGUAGE_DIALOG_H
