/********************************************************************************
** Form generated from reading UI file 'value_page.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef VALUE_PAGE_H
#define VALUE_PAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/elide_label.h"

QT_BEGIN_NAMESPACE

class Ui_Form
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *m_lTitle;
    QFrame *line;
    QGridLayout *gridLayout;
    QLabel *m_lTypeLabel;
    QLabel *m_lType;
    QLabel *m_lDescriptionLabel;
    QLabel *m_lDescription;
    QLabel *m_lStatusLabel;
    QVBoxLayout *verticalLayout_2;
    QLabel *m_lStatus;
    QCheckBox *m_cbAddOrRemove;
    QLabel *m_lOriginalValueLabel;
    mtx::gui::Util::ElideLabel *m_lOriginalValue;
    QLabel *m_lCurrentValueLabel;
    mtx::gui::Util::ElideLabel *m_lCurrentValue;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_bReset;

    void setupUi(QWidget *Form)
    {
        if (Form->objectName().isEmpty())
            Form->setObjectName("Form");
        Form->resize(504, 489);
        Form->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(Form);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, 0, 0, 0);
        m_lTitle = new QLabel(Form);
        m_lTitle->setObjectName("m_lTitle");
        m_lTitle->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(m_lTitle);

        line = new QFrame(Form);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        m_lTypeLabel = new QLabel(Form);
        m_lTypeLabel->setObjectName("m_lTypeLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_lTypeLabel->sizePolicy().hasHeightForWidth());
        m_lTypeLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_lTypeLabel, 0, 0, 1, 1, Qt::AlignTop);

        m_lType = new QLabel(Form);
        m_lType->setObjectName("m_lType");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_lType->sizePolicy().hasHeightForWidth());
        m_lType->setSizePolicy(sizePolicy1);
        m_lType->setText(QString::fromUtf8("TextLabel"));

        gridLayout->addWidget(m_lType, 0, 1, 1, 1);

        m_lDescriptionLabel = new QLabel(Form);
        m_lDescriptionLabel->setObjectName("m_lDescriptionLabel");
        sizePolicy.setHeightForWidth(m_lDescriptionLabel->sizePolicy().hasHeightForWidth());
        m_lDescriptionLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_lDescriptionLabel, 1, 0, 1, 1, Qt::AlignTop);

        m_lDescription = new QLabel(Form);
        m_lDescription->setObjectName("m_lDescription");
        sizePolicy1.setHeightForWidth(m_lDescription->sizePolicy().hasHeightForWidth());
        m_lDescription->setSizePolicy(sizePolicy1);
        m_lDescription->setText(QString::fromUtf8("TextLabel"));
        m_lDescription->setWordWrap(true);

        gridLayout->addWidget(m_lDescription, 1, 1, 1, 1);

        m_lStatusLabel = new QLabel(Form);
        m_lStatusLabel->setObjectName("m_lStatusLabel");
        sizePolicy.setHeightForWidth(m_lStatusLabel->sizePolicy().hasHeightForWidth());
        m_lStatusLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_lStatusLabel, 2, 0, 1, 1, Qt::AlignTop);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_lStatus = new QLabel(Form);
        m_lStatus->setObjectName("m_lStatus");
        sizePolicy1.setHeightForWidth(m_lStatus->sizePolicy().hasHeightForWidth());
        m_lStatus->setSizePolicy(sizePolicy1);
        m_lStatus->setText(QString::fromUtf8("TextLabel"));
        m_lStatus->setWordWrap(true);

        verticalLayout_2->addWidget(m_lStatus);

        m_cbAddOrRemove = new QCheckBox(Form);
        m_cbAddOrRemove->setObjectName("m_cbAddOrRemove");
        m_cbAddOrRemove->setText(QString::fromUtf8("CheckBox"));

        verticalLayout_2->addWidget(m_cbAddOrRemove);


        gridLayout->addLayout(verticalLayout_2, 2, 1, 1, 1);

        m_lOriginalValueLabel = new QLabel(Form);
        m_lOriginalValueLabel->setObjectName("m_lOriginalValueLabel");
        sizePolicy.setHeightForWidth(m_lOriginalValueLabel->sizePolicy().hasHeightForWidth());
        m_lOriginalValueLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_lOriginalValueLabel, 3, 0, 1, 1);

        m_lOriginalValue = new mtx::gui::Util::ElideLabel(Form);
        m_lOriginalValue->setObjectName("m_lOriginalValue");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_lOriginalValue->sizePolicy().hasHeightForWidth());
        m_lOriginalValue->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(m_lOriginalValue, 3, 1, 1, 1);

        m_lCurrentValueLabel = new QLabel(Form);
        m_lCurrentValueLabel->setObjectName("m_lCurrentValueLabel");
        sizePolicy.setHeightForWidth(m_lCurrentValueLabel->sizePolicy().hasHeightForWidth());
        m_lCurrentValueLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_lCurrentValueLabel, 4, 0, 1, 1, Qt::AlignTop);

        m_lCurrentValue = new mtx::gui::Util::ElideLabel(Form);
        m_lCurrentValue->setObjectName("m_lCurrentValue");
        sizePolicy2.setHeightForWidth(m_lCurrentValue->sizePolicy().hasHeightForWidth());
        m_lCurrentValue->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(m_lCurrentValue, 4, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_2 = new QSpacerItem(20, 279, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_bReset = new QPushButton(Form);
        m_bReset->setObjectName("m_bReset");
        m_bReset->setText(QString::fromUtf8("PushButton"));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-undo")));
        m_bReset->setIcon(icon);

        horizontalLayout->addWidget(m_bReset);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(Form);

        QMetaObject::connectSlotsByName(Form);
    } // setupUi

    void retranslateUi(QWidget *Form)
    {
        m_lTypeLabel->setText(QTR("Type:", nullptr));
        m_lDescriptionLabel->setText(QTR("Description:", nullptr));
        m_lStatusLabel->setText(QTR("Status:", nullptr));
        m_lOriginalValueLabel->setText(QTR("Original value:", nullptr));
        m_lCurrentValueLabel->setText(QTR("Current value:", nullptr));
        (void)Form;
    } // retranslateUi

};

namespace Ui {
    class Form: public Ui_Form {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VALUE_PAGE_H
