/********************************************************************************
** Form generated from reading UI file 'string_list_configuration_widget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef STRING_LIST_CONFIGURATION_WIDGET_H
#define STRING_LIST_CONFIGURATION_WIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {
namespace Util {

class Ui_StringListConfigurationWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QListWidget *lwItems;
    QVBoxLayout *verticalLayout;
    QPushButton *pbAddItem;
    QPushButton *pbRemoveItem;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *mtx__gui__Util__StringListConfigurationWidget)
    {
        if (mtx__gui__Util__StringListConfigurationWidget->objectName().isEmpty())
            mtx__gui__Util__StringListConfigurationWidget->setObjectName("mtx__gui__Util__StringListConfigurationWidget");
        mtx__gui__Util__StringListConfigurationWidget->resize(400, 300);
        mtx__gui__Util__StringListConfigurationWidget->setWindowTitle(QString::fromUtf8("StringListConfigurationWidget"));
        horizontalLayout = new QHBoxLayout(mtx__gui__Util__StringListConfigurationWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        lwItems = new QListWidget(mtx__gui__Util__StringListConfigurationWidget);
        lwItems->setObjectName("lwItems");
        lwItems->setDragEnabled(true);
        lwItems->setDragDropMode(QAbstractItemView::InternalMove);
        lwItems->setDefaultDropAction(Qt::MoveAction);
        lwItems->setAlternatingRowColors(true);
        lwItems->setSelectionMode(QAbstractItemView::ExtendedSelection);
        lwItems->setSortingEnabled(false);

        horizontalLayout->addWidget(lwItems);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        pbAddItem = new QPushButton(mtx__gui__Util__StringListConfigurationWidget);
        pbAddItem->setObjectName("pbAddItem");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        pbAddItem->setIcon(icon);

        verticalLayout->addWidget(pbAddItem);

        pbRemoveItem = new QPushButton(mtx__gui__Util__StringListConfigurationWidget);
        pbRemoveItem->setObjectName("pbRemoveItem");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        pbRemoveItem->setIcon(icon1);

        verticalLayout->addWidget(pbRemoveItem);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(mtx__gui__Util__StringListConfigurationWidget);

        QMetaObject::connectSlotsByName(mtx__gui__Util__StringListConfigurationWidget);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Util__StringListConfigurationWidget)
    {
        pbAddItem->setText(QString());
        pbRemoveItem->setText(QString());
        (void)mtx__gui__Util__StringListConfigurationWidget;
    } // retranslateUi

};

} // namespace Util
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Util {
namespace Ui {
    class StringListConfigurationWidget: public Ui_StringListConfigurationWidget {};
} // namespace Ui
} // namespace Util
} // namespace gui
} // namespace mtx

#endif // STRING_LIST_CONFIGURATION_WIDGET_H
