/********************************************************************************
** Form generated from reading UI file 'attached_file_page.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ATTACHED_FILE_PAGE_H
#define ATTACHED_FILE_PAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {
namespace HeaderEditor {

class Ui_AttachedFilePage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *heading;
    QFrame *line;
    QGridLayout *gridLayout;
    QLineEdit *description;
    QLineEdit *name;
    QLabel *nameLabel;
    QLabel *descriptionLabel;
    QLabel *size;
    QComboBox *mimeType;
    QLabel *sizeLabel;
    QLabel *mimeTypeLabel;
    QLabel *label;
    QLineEdit *uid;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *reset;

    void setupUi(QWidget *mtx__gui__HeaderEditor__AttachedFilePage)
    {
        if (mtx__gui__HeaderEditor__AttachedFilePage->objectName().isEmpty())
            mtx__gui__HeaderEditor__AttachedFilePage->setObjectName("mtx__gui__HeaderEditor__AttachedFilePage");
        mtx__gui__HeaderEditor__AttachedFilePage->resize(546, 361);
        mtx__gui__HeaderEditor__AttachedFilePage->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(mtx__gui__HeaderEditor__AttachedFilePage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, 0, 0, 0);
        heading = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        heading->setObjectName("heading");

        verticalLayout->addWidget(heading);

        line = new QFrame(mtx__gui__HeaderEditor__AttachedFilePage);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        description = new QLineEdit(mtx__gui__HeaderEditor__AttachedFilePage);
        description->setObjectName("description");
        description->setClearButtonEnabled(true);

        gridLayout->addWidget(description, 2, 1, 1, 1);

        name = new QLineEdit(mtx__gui__HeaderEditor__AttachedFilePage);
        name->setObjectName("name");
        name->setClearButtonEnabled(true);

        gridLayout->addWidget(name, 1, 1, 1, 1);

        nameLabel = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        nameLabel->setObjectName("nameLabel");

        gridLayout->addWidget(nameLabel, 1, 0, 1, 1);

        descriptionLabel = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        descriptionLabel->setObjectName("descriptionLabel");

        gridLayout->addWidget(descriptionLabel, 2, 0, 1, 1);

        size = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        size->setObjectName("size");
        size->setText(QString::fromUtf8("TextLabel"));

        gridLayout->addWidget(size, 0, 1, 1, 1);

        mimeType = new QComboBox(mtx__gui__HeaderEditor__AttachedFilePage);
        mimeType->setObjectName("mimeType");
        mimeType->setEditable(true);

        gridLayout->addWidget(mimeType, 3, 1, 1, 1);

        sizeLabel = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        sizeLabel->setObjectName("sizeLabel");

        gridLayout->addWidget(sizeLabel, 0, 0, 1, 1);

        mimeTypeLabel = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        mimeTypeLabel->setObjectName("mimeTypeLabel");

        gridLayout->addWidget(mimeTypeLabel, 3, 0, 1, 1);

        label = new QLabel(mtx__gui__HeaderEditor__AttachedFilePage);
        label->setObjectName("label");

        gridLayout->addWidget(label, 4, 0, 1, 1);

        uid = new QLineEdit(mtx__gui__HeaderEditor__AttachedFilePage);
        uid->setObjectName("uid");
        uid->setClearButtonEnabled(true);

        gridLayout->addWidget(uid, 4, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        reset = new QPushButton(mtx__gui__HeaderEditor__AttachedFilePage);
        reset->setObjectName("reset");
        reset->setText(QString::fromUtf8("&Reset"));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-undo")));
        reset->setIcon(icon);

        horizontalLayout->addWidget(reset);


        verticalLayout->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        nameLabel->setBuddy(name);
        descriptionLabel->setBuddy(description);
        mimeTypeLabel->setBuddy(mimeType);
        label->setBuddy(uid);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(name, description);
        QWidget::setTabOrder(description, mimeType);
        QWidget::setTabOrder(mimeType, uid);

        retranslateUi(mtx__gui__HeaderEditor__AttachedFilePage);

        QMetaObject::connectSlotsByName(mtx__gui__HeaderEditor__AttachedFilePage);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__HeaderEditor__AttachedFilePage)
    {
        heading->setText(QTR("Attachment", nullptr));
        nameLabel->setText(QTR("Fi&le name:", nullptr));
        descriptionLabel->setText(QTR("&Description:", nullptr));
        sizeLabel->setText(QTR("Size:", nullptr));
        mimeTypeLabel->setText(QTR("&MIME type:", nullptr));
        label->setText(QTR("&UID:", nullptr));
        (void)mtx__gui__HeaderEditor__AttachedFilePage;
    } // retranslateUi

};

} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace HeaderEditor {
namespace Ui {
    class AttachedFilePage: public Ui_AttachedFilePage {};
} // namespace Ui
} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

#endif // ATTACHED_FILE_PAGE_H
