/********************************************************************************
** Form generated from reading UI file 'tab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TAB_H
#define TAB_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_line_edit.h"
#include "mkvtoolnix-gui/util/basic_spin_box.h"
#include "mkvtoolnix-gui/util/basic_tree_view.h"
#include "mkvtoolnix-gui/util/character_set_combo_box.h"
#include "mkvtoolnix-gui/util/files_drag_drop_widget.h"
#include "mkvtoolnix-gui/util/language_display_widget.h"
#include "mkvtoolnix-gui/util/qgs_collapsible_group_box.h"

namespace mtx {
namespace gui {
namespace Merge {

class Ui_Tab
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabs;
    QWidget *inputTab;
    QHBoxLayout *horizontalLayout_2;
    QSplitter *mergeInputSplitter;
    QSplitter *mergeFilesTracksSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QLabel *filesLabel;
    QHBoxLayout *horizontalLayout_1;
    mtx::gui::Util::BasicTreeView *files;
    QWidget *moveFilesButtons;
    QVBoxLayout *verticalLayout_1;
    QPushButton *moveFilesUp;
    QPushButton *moveFilesDown;
    QSpacerItem *verticalSpacer_1;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout_5;
    QLabel *tracksLabel;
    QHBoxLayout *horizontalLayout_4;
    mtx::gui::Util::BasicTreeView *tracks;
    QWidget *moveTracksButtons;
    QVBoxLayout *verticalLayout_13;
    QPushButton *moveTracksUp;
    QPushButton *moveTracksDown;
    QSpacerItem *verticalSpacer;
    QTabWidget *twProperties;
    QWidget *generalOptionsPage;
    QVBoxLayout *verticalLayout_15;
    QSpacerItem *verticalSpacer_6;
    QWidget *timestampsAndDefaultDurationPage;
    QVBoxLayout *verticalLayout_16;
    QSpacerItem *verticalSpacer_7;
    QWidget *videoPropertiesPage;
    QVBoxLayout *verticalLayout_17;
    QSpacerItem *verticalSpacer_8;
    QWidget *colorInformationPage;
    QVBoxLayout *verticalLayout_25;
    QSpacerItem *verticalSpacer_13;
    QWidget *colorMasteringMetaInformationPage;
    QVBoxLayout *verticalLayout_26;
    QSpacerItem *verticalSpacer_14;
    QWidget *videoProjectionInformationPage;
    QVBoxLayout *verticalLayout_27;
    QSpacerItem *verticalSpacer_15;
    QWidget *audioSubtitleChapterPropertiesPage;
    QVBoxLayout *verticalLayout_18;
    QSpacerItem *verticalSpacer_9;
    QWidget *miscellaneousPage;
    QVBoxLayout *verticalLayout_19;
    QSpacerItem *verticalSpacer_10;
    QWidget *wProperties;
    QVBoxLayout *verticalLayout_4;
    QLabel *propertiesLabel;
    QStackedWidget *propertiesStack;
    QWidget *propertiesScrollAreaPage;
    QVBoxLayout *verticalLayout_20;
    QScrollArea *propertiesScrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_9;
    mtx::gui::Util::QgsCollapsibleGroupBox *generalOptionsBox;
    QGridLayout *gridLayout_3;
    QLabel *defaultTrackFlagLabel;
    QLabel *textDescriptionsFlagLabel;
    QComboBox *trackName;
    QComboBox *forcedTrackFlag;
    QComboBox *compression;
    QComboBox *commentaryFlag;
    QLabel *forcedTrackFlagLabel;
    QLabel *muxThisLabel;
    QComboBox *textDescriptionsFlag;
    QLabel *hearingImpairedFlagLabel;
    QComboBox *muxThis;
    QLabel *trackLanguageLabel;
    QComboBox *defaultTrackFlag;
    mtx::gui::Util::LanguageDisplayWidget *trackLanguage;
    QLabel *visualImpairedFlagLabel;
    QLabel *originalFlagLabel;
    QWidget *trackTagsContainer;
    QHBoxLayout *horizontalLayout_11;
    mtx::gui::Util::BasicLineEdit *trackTags;
    QPushButton *browseTrackTags;
    QLabel *trackNameLabel;
    QComboBox *originalFlag;
    QComboBox *visualImpairedFlag;
    QLabel *trackTagsLabel;
    QLabel *compressionLabel;
    QComboBox *hearingImpairedFlag;
    QLabel *commentaryFlagLabel;
    QLabel *trackEnabledFlagLabel;
    QComboBox *trackEnabledFlag;
    mtx::gui::Util::QgsCollapsibleGroupBox *timestampsAndDefaultDurationBox;
    QVBoxLayout *verticalLayout_11;
    QGridLayout *gridLayout_6;
    QLabel *delayLabel;
    QLineEdit *delay;
    QLabel *stretchByLabel;
    QLineEdit *stretchBy;
    QLabel *defaultDurationLabel;
    QComboBox *defaultDuration;
    QLabel *timestampsLabel;
    QHBoxLayout *horizontalLayout_12;
    mtx::gui::Util::BasicLineEdit *timestamps;
    QPushButton *browseTimestamps;
    QCheckBox *fixBitstreamTimingInfo;
    mtx::gui::Util::QgsCollapsibleGroupBox *videoPropertiesBox;
    QGridLayout *gridLayout_7;
    QRadioButton *setDisplayWidthHeight;
    QLineEdit *cropping;
    QLabel *stereoscopyLabel;
    QComboBox *stereoscopy;
    QLabel *croppingLabel;
    QRadioButton *setAspectRatio;
    QHBoxLayout *horizontalLayout_14;
    QLineEdit *displayWidth;
    QLabel *displayDimensionsXLabel;
    QLineEdit *displayHeight;
    QComboBox *aspectRatio;
    mtx::gui::Util::QgsCollapsibleGroupBox *colorInformationBox;
    QGridLayout *gridLayout_4;
    QLabel *transferCharacteristicsLabel;
    QLineEdit *colorRange;
    QLabel *bitsPerColorChannelLabel;
    QLabel *colorPrimariesLabel;
    QLabel *cbSubsamplingLabel;
    QLineEdit *chromaSubsampling;
    QLineEdit *maximumContentLight;
    QLabel *maximumContentLightLabel;
    QLineEdit *chromaSiting;
    QLineEdit *transferCharacteristics;
    QLabel *maximumFrameLightLabel;
    QLabel *chromaSubsamplingLabel;
    QLabel *colorMatrixCoefficientsLabel;
    QLineEdit *bitsPerColorChannel;
    QLineEdit *colorPrimaries;
    QLabel *colorRangeLabel;
    QLineEdit *cbSubsampling;
    QLineEdit *colorMatrixCoefficients;
    QLineEdit *maximumFrameLight;
    QLabel *chromaSitingLabel;
    mtx::gui::Util::QgsCollapsibleGroupBox *colorMasteringMetaInformationBox;
    QGridLayout *gridLayout_5;
    QLabel *maximumLuminanceLabel;
    QLabel *chromaticityCoordinatesLabel;
    QLineEdit *whiteColorCoordinates;
    QLabel *whiteColorCoordinatesLabel;
    QLabel *minimumLuminanceLabel;
    QLineEdit *maximumLuminance;
    QLineEdit *minimumLuminance;
    QLineEdit *chromaticityCoordinates;
    mtx::gui::Util::QgsCollapsibleGroupBox *videoProjectionInformationBox;
    QGridLayout *gridLayout_10;
    QLabel *projectionTypeLabel;
    QLineEdit *projectionSpecificData;
    QLineEdit *yawRotation;
    QLabel *pitchRotationLabel;
    QLineEdit *projectionType;
    QLabel *yawRotationLabel;
    QLabel *projectionSpecificDataLabel;
    QLineEdit *pitchRotation;
    QLabel *rollRotationLabel;
    QLineEdit *rollRotation;
    mtx::gui::Util::QgsCollapsibleGroupBox *audioPropertiesBox;
    QVBoxLayout *verticalLayout_12;
    QGridLayout *gridLayout_11;
    QLabel *aacIsSBRLabel;
    QComboBox *aacIsSBR;
    QLabel *audioEmphasisLabel;
    QComboBox *audioEmphasis;
    QCheckBox *reduceToAudioCore;
    QCheckBox *removeDialogNormalizationGain;
    mtx::gui::Util::QgsCollapsibleGroupBox *subtitleAndChapterPropertiesBox;
    QHBoxLayout *horizontalLayout_16;
    QLabel *characterSetLabel;
    mtx::gui::Util::CharacterSetComboBox *subtitleCharacterSet;
    QPushButton *subtitleCharacterSetPreview;
    mtx::gui::Util::QgsCollapsibleGroupBox *miscellaneousBox;
    QGridLayout *gridLayout_9;
    QLabel *cuesLabel;
    QComboBox *cues;
    QLabel *additionalTrackOptionsLabel;
    QLineEdit *additionalTrackOptions;
    QSpacerItem *verticalSpacer_5;
    QWidget *propertiesTwoColumnsPage;
    QHBoxLayout *horizontalLayout_17;
    QWidget *propertiesColumn1;
    QVBoxLayout *verticalLayout_21;
    QSpacerItem *verticalSpacer_11;
    QWidget *propertiesColumn2;
    QVBoxLayout *verticalLayout_22;
    QSpacerItem *verticalSpacer_12;
    QWidget *outputTab;
    QVBoxLayout *verticalLayout_3;
    QSplitter *mergeOutputSplitter;
    QWidget *layoutWidget4;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *generalBox;
    QGridLayout *generalGridLayout;
    QHBoxLayout *hlOutput;
    mtx::gui::Util::BasicLineEdit *output;
    QPushButton *browseOutput;
    QPushButton *outputRecentlyUsed;
    QLabel *globalTagsLabel;
    QLabel *segmentInfoLabel;
    QHBoxLayout *horizontalLayout_8;
    mtx::gui::Util::BasicLineEdit *segmentInfo;
    QPushButton *browseSegmentInfo;
    QLabel *outputLabel;
    QHBoxLayout *horizontalLayout_7;
    mtx::gui::Util::BasicLineEdit *globalTags;
    QPushButton *browseGlobalTags;
    QLabel *titleLael;
    QLineEdit *title;
    QGroupBox *splittingBox;
    QGridLayout *gridLayout_2;
    QLabel *splitModeLabel;
    QComboBox *splitMode;
    QComboBox *splitOptions;
    QLabel *splitMaxFilesLabel;
    mtx::gui::Util::BasicSpinBox *splitMaxFiles;
    QCheckBox *linkFiles;
    QLabel *splitOptionsLabel;
    QGroupBox *outputMischellaneousBox;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *webmMode;
    QCheckBox *stopAfterVideoEnds;
    QHBoxLayout *horizontalLayout_10;
    QLabel *additionalOptionsLabel;
    QLineEdit *additionalOptions;
    QPushButton *editAdditionalOptions;
    QSpacerItem *verticalSpacer_3;
    QWidget *layoutWidget5;
    QVBoxLayout *verticalLayout_8;
    QGroupBox *fileSegmentLinkingBox;
    QGridLayout *gridLayout1;
    QLabel *segmentUIDsLabel;
    QHBoxLayout *horizontalLayout_61;
    QLineEdit *segmentUIDs;
    QPushButton *browseSegmentUID;
    QLabel *previousSegmentUIDLabel;
    QHBoxLayout *horizontalLayout_13;
    QLineEdit *previousSegmentUID;
    QPushButton *browsePreviousSegmentUID;
    QLabel *nextSegmentUIDLabel;
    QHBoxLayout *horizontalLayout_15;
    QLineEdit *nextSegmentUID;
    QPushButton *browseNextSegmentUID;
    QGroupBox *chaptersBox;
    QGridLayout *gridLayout;
    QLineEdit *chapterStretchBy;
    QLabel *chaptersLabel;
    QLabel *chapterGenerationNameTemplateLabel;
    QLabel *chapterGenerationIntervalLabel;
    mtx::gui::Util::LanguageDisplayWidget *chapterLanguage;
    QHBoxLayout *horizontalLayout_6;
    mtx::gui::Util::CharacterSetComboBox *chapterCharacterSet;
    QPushButton *chapterCharacterSetPreview;
    QLabel *chapterCueNameFormatLabel;
    QLineEdit *chapterGenerationNameTemplate;
    QLabel *chapterGenerationLabel;
    QLabel *chapterStretchByLabel;
    QLineEdit *chapterCueNameFormat;
    QComboBox *chapterGenerationMode;
    QLabel *chapterCharacterSetLabel;
    QLineEdit *chapterGenerationInterval;
    QLineEdit *chapterDelay;
    QHBoxLayout *horizontalLayout_9;
    mtx::gui::Util::BasicLineEdit *chapters;
    QPushButton *browseChapters;
    QLabel *chapterLanguageLabel;
    QLabel *chapterDelayLabel;
    QLabel *chapterTitleNumberLabel;
    mtx::gui::Util::BasicSpinBox *chapterTitleNumber;
    QSpacerItem *verticalSpacer_4;
    mtx::gui::Util::FilesDragDropWidget *attachmentsTab;
    QVBoxLayout *verticalLayout_24;
    QSplitter *mergeAttachmentsSplitter;
    QWidget *layoutWidget2;
    QVBoxLayout *verticalLayout_23;
    QLabel *attachedFilesLabel;
    mtx::gui::Util::BasicTreeView *attachedFiles;
    QWidget *layoutWidget3;
    QVBoxLayout *verticalLayout_14;
    QLabel *attachmentsLabel;
    QHBoxLayout *horizontalLayout_5;
    mtx::gui::Util::BasicTreeView *attachments;
    QWidget *moveAttachmentsButtons;
    QVBoxLayout *verticalLayout_10;
    QPushButton *moveAttachmentsUp;
    QPushButton *moveAttachmentsDown;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *attachmentSettingsBox;
    QGridLayout *gridLayout_8;
    QLabel *attachmentNameLabel;
    QLineEdit *attachmentName;
    QLabel *attachmentDescriptionLabel;
    QLineEdit *attachmentDescription;
    QLabel *attachmentMIMETypeLabel;
    QComboBox *attachmentMIMEType;
    QLabel *attachmentStyleLabel;
    QComboBox *attachmentStyle;
    QGroupBox *gbOutputFile;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *addFiles;
    QToolButton *startMuxing;
    QToolButton *addToJobQueue;
    QSpacerItem *horizontalSpacer_3;

    void setupUi(QWidget *mtx__gui__Merge__Tab)
    {
        if (mtx__gui__Merge__Tab->objectName().isEmpty())
            mtx__gui__Merge__Tab->setObjectName("mtx__gui__Merge__Tab");
        mtx__gui__Merge__Tab->resize(898, 659);
        mtx__gui__Merge__Tab->setWindowTitle(QString::fromUtf8("mtx::gui::Merge::Tab"));
        verticalLayout_2 = new QVBoxLayout(mtx__gui__Merge__Tab);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        tabs = new QTabWidget(mtx__gui__Merge__Tab);
        tabs->setObjectName("tabs");
        tabs->setTabPosition(QTabWidget::North);
        inputTab = new QWidget();
        inputTab->setObjectName("inputTab");
        horizontalLayout_2 = new QHBoxLayout(inputTab);
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mergeInputSplitter = new QSplitter(inputTab);
        mergeInputSplitter->setObjectName("mergeInputSplitter");
        mergeInputSplitter->setOrientation(Qt::Horizontal);
        mergeInputSplitter->setChildrenCollapsible(false);
        mergeFilesTracksSplitter = new QSplitter(mergeInputSplitter);
        mergeFilesTracksSplitter->setObjectName("mergeFilesTracksSplitter");
        mergeFilesTracksSplitter->setOrientation(Qt::Vertical);
        mergeFilesTracksSplitter->setChildrenCollapsible(false);
        layoutWidget = new QWidget(mergeFilesTracksSplitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        filesLabel = new QLabel(layoutWidget);
        filesLabel->setObjectName("filesLabel");

        verticalLayout->addWidget(filesLabel);

        horizontalLayout_1 = new QHBoxLayout();
        horizontalLayout_1->setSpacing(6);
        horizontalLayout_1->setObjectName("horizontalLayout_1");
        files = new mtx::gui::Util::BasicTreeView(layoutWidget);
        files->setObjectName("files");
        files->setMinimumSize(QSize(370, 0));
        files->setContextMenuPolicy(Qt::CustomContextMenu);
        files->setAcceptDrops(true);
        files->setEditTriggers(QAbstractItemView::NoEditTriggers);
        files->setDragEnabled(true);
        files->setDragDropMode(QAbstractItemView::InternalMove);
        files->setDefaultDropAction(Qt::MoveAction);
        files->setAlternatingRowColors(false);
        files->setSelectionMode(QAbstractItemView::ExtendedSelection);

        horizontalLayout_1->addWidget(files);

        moveFilesButtons = new QWidget(layoutWidget);
        moveFilesButtons->setObjectName("moveFilesButtons");
        verticalLayout_1 = new QVBoxLayout(moveFilesButtons);
        verticalLayout_1->setSpacing(6);
        verticalLayout_1->setContentsMargins(11, 11, 11, 11);
        verticalLayout_1->setObjectName("verticalLayout_1");
        verticalLayout_1->setContentsMargins(0, 0, 0, 0);
        moveFilesUp = new QPushButton(moveFilesButtons);
        moveFilesUp->setObjectName("moveFilesUp");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("arrow-up");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        moveFilesUp->setIcon(icon);

        verticalLayout_1->addWidget(moveFilesUp);

        moveFilesDown = new QPushButton(moveFilesButtons);
        moveFilesDown->setObjectName("moveFilesDown");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("arrow-down");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        moveFilesDown->setIcon(icon1);

        verticalLayout_1->addWidget(moveFilesDown);

        verticalSpacer_1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_1->addItem(verticalSpacer_1);


        horizontalLayout_1->addWidget(moveFilesButtons);


        verticalLayout->addLayout(horizontalLayout_1);

        mergeFilesTracksSplitter->addWidget(layoutWidget);
        layoutWidget1 = new QWidget(mergeFilesTracksSplitter);
        layoutWidget1->setObjectName("layoutWidget1");
        verticalLayout_5 = new QVBoxLayout(layoutWidget1);
        verticalLayout_5->setSpacing(6);
        verticalLayout_5->setContentsMargins(11, 11, 11, 11);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        tracksLabel = new QLabel(layoutWidget1);
        tracksLabel->setObjectName("tracksLabel");

        verticalLayout_5->addWidget(tracksLabel);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(6);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        tracks = new mtx::gui::Util::BasicTreeView(layoutWidget1);
        tracks->setObjectName("tracks");
        tracks->setContextMenuPolicy(Qt::CustomContextMenu);
        tracks->setAcceptDrops(true);
        tracks->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tracks->setDragEnabled(true);
        tracks->setDragDropMode(QAbstractItemView::InternalMove);
        tracks->setDefaultDropAction(Qt::MoveAction);
        tracks->setSelectionMode(QAbstractItemView::ExtendedSelection);
        tracks->setExpandsOnDoubleClick(false);

        horizontalLayout_4->addWidget(tracks);

        moveTracksButtons = new QWidget(layoutWidget1);
        moveTracksButtons->setObjectName("moveTracksButtons");
        verticalLayout_13 = new QVBoxLayout(moveTracksButtons);
        verticalLayout_13->setSpacing(6);
        verticalLayout_13->setContentsMargins(11, 11, 11, 11);
        verticalLayout_13->setObjectName("verticalLayout_13");
        verticalLayout_13->setContentsMargins(0, 0, 0, 0);
        moveTracksUp = new QPushButton(moveTracksButtons);
        moveTracksUp->setObjectName("moveTracksUp");
        moveTracksUp->setIcon(icon);

        verticalLayout_13->addWidget(moveTracksUp);

        moveTracksDown = new QPushButton(moveTracksButtons);
        moveTracksDown->setObjectName("moveTracksDown");
        moveTracksDown->setIcon(icon1);

        verticalLayout_13->addWidget(moveTracksDown);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_13->addItem(verticalSpacer);


        horizontalLayout_4->addWidget(moveTracksButtons);


        verticalLayout_5->addLayout(horizontalLayout_4);

        mergeFilesTracksSplitter->addWidget(layoutWidget1);
        twProperties = new QTabWidget(mergeFilesTracksSplitter);
        twProperties->setObjectName("twProperties");
        generalOptionsPage = new QWidget();
        generalOptionsPage->setObjectName("generalOptionsPage");
        verticalLayout_15 = new QVBoxLayout(generalOptionsPage);
        verticalLayout_15->setSpacing(6);
        verticalLayout_15->setContentsMargins(11, 11, 11, 11);
        verticalLayout_15->setObjectName("verticalLayout_15");
        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_15->addItem(verticalSpacer_6);

        twProperties->addTab(generalOptionsPage, QString());
        timestampsAndDefaultDurationPage = new QWidget();
        timestampsAndDefaultDurationPage->setObjectName("timestampsAndDefaultDurationPage");
        verticalLayout_16 = new QVBoxLayout(timestampsAndDefaultDurationPage);
        verticalLayout_16->setSpacing(6);
        verticalLayout_16->setContentsMargins(11, 11, 11, 11);
        verticalLayout_16->setObjectName("verticalLayout_16");
        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_16->addItem(verticalSpacer_7);

        twProperties->addTab(timestampsAndDefaultDurationPage, QString());
        videoPropertiesPage = new QWidget();
        videoPropertiesPage->setObjectName("videoPropertiesPage");
        verticalLayout_17 = new QVBoxLayout(videoPropertiesPage);
        verticalLayout_17->setSpacing(6);
        verticalLayout_17->setContentsMargins(11, 11, 11, 11);
        verticalLayout_17->setObjectName("verticalLayout_17");
        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_17->addItem(verticalSpacer_8);

        twProperties->addTab(videoPropertiesPage, QString());
        colorInformationPage = new QWidget();
        colorInformationPage->setObjectName("colorInformationPage");
        verticalLayout_25 = new QVBoxLayout(colorInformationPage);
        verticalLayout_25->setSpacing(6);
        verticalLayout_25->setContentsMargins(11, 11, 11, 11);
        verticalLayout_25->setObjectName("verticalLayout_25");
        verticalSpacer_13 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_25->addItem(verticalSpacer_13);

        twProperties->addTab(colorInformationPage, QString());
        colorMasteringMetaInformationPage = new QWidget();
        colorMasteringMetaInformationPage->setObjectName("colorMasteringMetaInformationPage");
        verticalLayout_26 = new QVBoxLayout(colorMasteringMetaInformationPage);
        verticalLayout_26->setSpacing(6);
        verticalLayout_26->setContentsMargins(11, 11, 11, 11);
        verticalLayout_26->setObjectName("verticalLayout_26");
        verticalSpacer_14 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_26->addItem(verticalSpacer_14);

        twProperties->addTab(colorMasteringMetaInformationPage, QString());
        videoProjectionInformationPage = new QWidget();
        videoProjectionInformationPage->setObjectName("videoProjectionInformationPage");
        verticalLayout_27 = new QVBoxLayout(videoProjectionInformationPage);
        verticalLayout_27->setSpacing(6);
        verticalLayout_27->setContentsMargins(11, 11, 11, 11);
        verticalLayout_27->setObjectName("verticalLayout_27");
        verticalSpacer_15 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_27->addItem(verticalSpacer_15);

        twProperties->addTab(videoProjectionInformationPage, QString());
        audioSubtitleChapterPropertiesPage = new QWidget();
        audioSubtitleChapterPropertiesPage->setObjectName("audioSubtitleChapterPropertiesPage");
        verticalLayout_18 = new QVBoxLayout(audioSubtitleChapterPropertiesPage);
        verticalLayout_18->setSpacing(6);
        verticalLayout_18->setContentsMargins(11, 11, 11, 11);
        verticalLayout_18->setObjectName("verticalLayout_18");
        verticalSpacer_9 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_18->addItem(verticalSpacer_9);

        twProperties->addTab(audioSubtitleChapterPropertiesPage, QString());
        miscellaneousPage = new QWidget();
        miscellaneousPage->setObjectName("miscellaneousPage");
        verticalLayout_19 = new QVBoxLayout(miscellaneousPage);
        verticalLayout_19->setSpacing(6);
        verticalLayout_19->setContentsMargins(11, 11, 11, 11);
        verticalLayout_19->setObjectName("verticalLayout_19");
        verticalSpacer_10 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_19->addItem(verticalSpacer_10);

        twProperties->addTab(miscellaneousPage, QString());
        mergeFilesTracksSplitter->addWidget(twProperties);
        mergeInputSplitter->addWidget(mergeFilesTracksSplitter);
        wProperties = new QWidget(mergeInputSplitter);
        wProperties->setObjectName("wProperties");
        verticalLayout_4 = new QVBoxLayout(wProperties);
        verticalLayout_4->setSpacing(6);
        verticalLayout_4->setContentsMargins(11, 11, 11, 11);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        propertiesLabel = new QLabel(wProperties);
        propertiesLabel->setObjectName("propertiesLabel");

        verticalLayout_4->addWidget(propertiesLabel);

        propertiesStack = new QStackedWidget(wProperties);
        propertiesStack->setObjectName("propertiesStack");
        propertiesScrollAreaPage = new QWidget();
        propertiesScrollAreaPage->setObjectName("propertiesScrollAreaPage");
        verticalLayout_20 = new QVBoxLayout(propertiesScrollAreaPage);
        verticalLayout_20->setSpacing(6);
        verticalLayout_20->setContentsMargins(11, 11, 11, 11);
        verticalLayout_20->setObjectName("verticalLayout_20");
        verticalLayout_20->setContentsMargins(0, 0, 0, 0);
        propertiesScrollArea = new QScrollArea(propertiesScrollAreaPage);
        propertiesScrollArea->setObjectName("propertiesScrollArea");
        propertiesScrollArea->setMinimumSize(QSize(370, 0));
        propertiesScrollArea->setFrameShape(QFrame::Box);
        propertiesScrollArea->setFrameShadow(QFrame::Plain);
        propertiesScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        propertiesScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 430, 1921));
        verticalLayout_9 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_9->setSpacing(6);
        verticalLayout_9->setContentsMargins(11, 11, 11, 11);
        verticalLayout_9->setObjectName("verticalLayout_9");
        generalOptionsBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        generalOptionsBox->setObjectName("generalOptionsBox");
        gridLayout_3 = new QGridLayout(generalOptionsBox);
        gridLayout_3->setSpacing(6);
        gridLayout_3->setContentsMargins(11, 11, 11, 11);
        gridLayout_3->setObjectName("gridLayout_3");
        defaultTrackFlagLabel = new QLabel(generalOptionsBox);
        defaultTrackFlagLabel->setObjectName("defaultTrackFlagLabel");

        gridLayout_3->addWidget(defaultTrackFlagLabel, 3, 0, 1, 1);

        textDescriptionsFlagLabel = new QLabel(generalOptionsBox);
        textDescriptionsFlagLabel->setObjectName("textDescriptionsFlagLabel");

        gridLayout_3->addWidget(textDescriptionsFlagLabel, 8, 0, 1, 1);

        trackName = new QComboBox(generalOptionsBox);
        trackName->setObjectName("trackName");
        trackName->setEditable(true);

        gridLayout_3->addWidget(trackName, 1, 1, 1, 1);

        forcedTrackFlag = new QComboBox(generalOptionsBox);
        forcedTrackFlag->setObjectName("forcedTrackFlag");

        gridLayout_3->addWidget(forcedTrackFlag, 5, 1, 1, 1);

        compression = new QComboBox(generalOptionsBox);
        compression->setObjectName("compression");

        gridLayout_3->addWidget(compression, 11, 1, 1, 1);

        commentaryFlag = new QComboBox(generalOptionsBox);
        commentaryFlag->setObjectName("commentaryFlag");

        gridLayout_3->addWidget(commentaryFlag, 10, 1, 1, 1);

        forcedTrackFlagLabel = new QLabel(generalOptionsBox);
        forcedTrackFlagLabel->setObjectName("forcedTrackFlagLabel");

        gridLayout_3->addWidget(forcedTrackFlagLabel, 5, 0, 1, 1);

        muxThisLabel = new QLabel(generalOptionsBox);
        muxThisLabel->setObjectName("muxThisLabel");

        gridLayout_3->addWidget(muxThisLabel, 0, 0, 1, 1);

        textDescriptionsFlag = new QComboBox(generalOptionsBox);
        textDescriptionsFlag->setObjectName("textDescriptionsFlag");

        gridLayout_3->addWidget(textDescriptionsFlag, 8, 1, 1, 1);

        hearingImpairedFlagLabel = new QLabel(generalOptionsBox);
        hearingImpairedFlagLabel->setObjectName("hearingImpairedFlagLabel");

        gridLayout_3->addWidget(hearingImpairedFlagLabel, 6, 0, 1, 1);

        muxThis = new QComboBox(generalOptionsBox);
        muxThis->setObjectName("muxThis");

        gridLayout_3->addWidget(muxThis, 0, 1, 1, 1);

        trackLanguageLabel = new QLabel(generalOptionsBox);
        trackLanguageLabel->setObjectName("trackLanguageLabel");

        gridLayout_3->addWidget(trackLanguageLabel, 2, 0, 1, 1);

        defaultTrackFlag = new QComboBox(generalOptionsBox);
        defaultTrackFlag->setObjectName("defaultTrackFlag");

        gridLayout_3->addWidget(defaultTrackFlag, 3, 1, 1, 1);

        trackLanguage = new mtx::gui::Util::LanguageDisplayWidget(generalOptionsBox);
        trackLanguage->setObjectName("trackLanguage");
        trackLanguage->setFocusPolicy(Qt::TabFocus);

        gridLayout_3->addWidget(trackLanguage, 2, 1, 1, 1);

        visualImpairedFlagLabel = new QLabel(generalOptionsBox);
        visualImpairedFlagLabel->setObjectName("visualImpairedFlagLabel");

        gridLayout_3->addWidget(visualImpairedFlagLabel, 7, 0, 1, 1);

        originalFlagLabel = new QLabel(generalOptionsBox);
        originalFlagLabel->setObjectName("originalFlagLabel");

        gridLayout_3->addWidget(originalFlagLabel, 9, 0, 1, 1);

        trackTagsContainer = new QWidget(generalOptionsBox);
        trackTagsContainer->setObjectName("trackTagsContainer");
        horizontalLayout_11 = new QHBoxLayout(trackTagsContainer);
        horizontalLayout_11->setSpacing(6);
        horizontalLayout_11->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        horizontalLayout_11->setContentsMargins(0, 0, 0, 0);
        trackTags = new mtx::gui::Util::BasicLineEdit(trackTagsContainer);
        trackTags->setObjectName("trackTags");

        horizontalLayout_11->addWidget(trackTags);

        browseTrackTags = new QPushButton(trackTagsContainer);
        browseTrackTags->setObjectName("browseTrackTags");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        browseTrackTags->setIcon(icon2);

        horizontalLayout_11->addWidget(browseTrackTags);


        gridLayout_3->addWidget(trackTagsContainer, 12, 1, 1, 1);

        trackNameLabel = new QLabel(generalOptionsBox);
        trackNameLabel->setObjectName("trackNameLabel");

        gridLayout_3->addWidget(trackNameLabel, 1, 0, 1, 1);

        originalFlag = new QComboBox(generalOptionsBox);
        originalFlag->setObjectName("originalFlag");

        gridLayout_3->addWidget(originalFlag, 9, 1, 1, 1);

        visualImpairedFlag = new QComboBox(generalOptionsBox);
        visualImpairedFlag->setObjectName("visualImpairedFlag");

        gridLayout_3->addWidget(visualImpairedFlag, 7, 1, 1, 1);

        trackTagsLabel = new QLabel(generalOptionsBox);
        trackTagsLabel->setObjectName("trackTagsLabel");

        gridLayout_3->addWidget(trackTagsLabel, 12, 0, 1, 1);

        compressionLabel = new QLabel(generalOptionsBox);
        compressionLabel->setObjectName("compressionLabel");

        gridLayout_3->addWidget(compressionLabel, 11, 0, 1, 1);

        hearingImpairedFlag = new QComboBox(generalOptionsBox);
        hearingImpairedFlag->setObjectName("hearingImpairedFlag");

        gridLayout_3->addWidget(hearingImpairedFlag, 6, 1, 1, 1);

        commentaryFlagLabel = new QLabel(generalOptionsBox);
        commentaryFlagLabel->setObjectName("commentaryFlagLabel");

        gridLayout_3->addWidget(commentaryFlagLabel, 10, 0, 1, 1);

        trackEnabledFlagLabel = new QLabel(generalOptionsBox);
        trackEnabledFlagLabel->setObjectName("trackEnabledFlagLabel");

        gridLayout_3->addWidget(trackEnabledFlagLabel, 4, 0, 1, 1);

        trackEnabledFlag = new QComboBox(generalOptionsBox);
        trackEnabledFlag->setObjectName("trackEnabledFlag");

        gridLayout_3->addWidget(trackEnabledFlag, 4, 1, 1, 1);


        verticalLayout_9->addWidget(generalOptionsBox);

        timestampsAndDefaultDurationBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        timestampsAndDefaultDurationBox->setObjectName("timestampsAndDefaultDurationBox");
        verticalLayout_11 = new QVBoxLayout(timestampsAndDefaultDurationBox);
        verticalLayout_11->setSpacing(6);
        verticalLayout_11->setContentsMargins(11, 11, 11, 11);
        verticalLayout_11->setObjectName("verticalLayout_11");
        gridLayout_6 = new QGridLayout();
        gridLayout_6->setSpacing(6);
        gridLayout_6->setObjectName("gridLayout_6");
        delayLabel = new QLabel(timestampsAndDefaultDurationBox);
        delayLabel->setObjectName("delayLabel");

        gridLayout_6->addWidget(delayLabel, 0, 0, 1, 1);

        delay = new QLineEdit(timestampsAndDefaultDurationBox);
        delay->setObjectName("delay");
        delay->setClearButtonEnabled(true);

        gridLayout_6->addWidget(delay, 0, 1, 1, 1);

        stretchByLabel = new QLabel(timestampsAndDefaultDurationBox);
        stretchByLabel->setObjectName("stretchByLabel");

        gridLayout_6->addWidget(stretchByLabel, 1, 0, 1, 1);

        stretchBy = new QLineEdit(timestampsAndDefaultDurationBox);
        stretchBy->setObjectName("stretchBy");
        stretchBy->setClearButtonEnabled(true);

        gridLayout_6->addWidget(stretchBy, 1, 1, 1, 1);

        defaultDurationLabel = new QLabel(timestampsAndDefaultDurationBox);
        defaultDurationLabel->setObjectName("defaultDurationLabel");

        gridLayout_6->addWidget(defaultDurationLabel, 2, 0, 1, 1);

        defaultDuration = new QComboBox(timestampsAndDefaultDurationBox);
        defaultDuration->addItem(QString::fromUtf8(""));
        defaultDuration->addItem(QString::fromUtf8("24p"));
        defaultDuration->addItem(QString::fromUtf8("25p"));
        defaultDuration->addItem(QString::fromUtf8("30p"));
        defaultDuration->addItem(QString::fromUtf8("48p"));
        defaultDuration->addItem(QString::fromUtf8("50i"));
        defaultDuration->addItem(QString::fromUtf8("50p"));
        defaultDuration->addItem(QString::fromUtf8("60i"));
        defaultDuration->addItem(QString::fromUtf8("60p"));
        defaultDuration->addItem(QString::fromUtf8("24000/1001p"));
        defaultDuration->addItem(QString::fromUtf8("30000/1001p"));
        defaultDuration->addItem(QString::fromUtf8("48000/1001p"));
        defaultDuration->addItem(QString::fromUtf8("60000/1001i"));
        defaultDuration->addItem(QString::fromUtf8("60000/1001p"));
        defaultDuration->setObjectName("defaultDuration");
        defaultDuration->setEditable(true);

        gridLayout_6->addWidget(defaultDuration, 2, 1, 1, 1);

        timestampsLabel = new QLabel(timestampsAndDefaultDurationBox);
        timestampsLabel->setObjectName("timestampsLabel");

        gridLayout_6->addWidget(timestampsLabel, 3, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setSpacing(6);
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        timestamps = new mtx::gui::Util::BasicLineEdit(timestampsAndDefaultDurationBox);
        timestamps->setObjectName("timestamps");

        horizontalLayout_12->addWidget(timestamps);

        browseTimestamps = new QPushButton(timestampsAndDefaultDurationBox);
        browseTimestamps->setObjectName("browseTimestamps");
        browseTimestamps->setIcon(icon2);

        horizontalLayout_12->addWidget(browseTimestamps);


        gridLayout_6->addLayout(horizontalLayout_12, 3, 1, 1, 1);


        verticalLayout_11->addLayout(gridLayout_6);

        fixBitstreamTimingInfo = new QCheckBox(timestampsAndDefaultDurationBox);
        fixBitstreamTimingInfo->setObjectName("fixBitstreamTimingInfo");

        verticalLayout_11->addWidget(fixBitstreamTimingInfo);


        verticalLayout_9->addWidget(timestampsAndDefaultDurationBox);

        videoPropertiesBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        videoPropertiesBox->setObjectName("videoPropertiesBox");
        gridLayout_7 = new QGridLayout(videoPropertiesBox);
        gridLayout_7->setSpacing(6);
        gridLayout_7->setContentsMargins(11, 11, 11, 11);
        gridLayout_7->setObjectName("gridLayout_7");
        setDisplayWidthHeight = new QRadioButton(videoPropertiesBox);
        setDisplayWidthHeight->setObjectName("setDisplayWidthHeight");

        gridLayout_7->addWidget(setDisplayWidthHeight, 1, 0, 1, 1);

        cropping = new QLineEdit(videoPropertiesBox);
        cropping->setObjectName("cropping");
        cropping->setClearButtonEnabled(true);

        gridLayout_7->addWidget(cropping, 3, 1, 1, 1);

        stereoscopyLabel = new QLabel(videoPropertiesBox);
        stereoscopyLabel->setObjectName("stereoscopyLabel");

        gridLayout_7->addWidget(stereoscopyLabel, 5, 0, 1, 1);

        stereoscopy = new QComboBox(videoPropertiesBox);
        stereoscopy->setObjectName("stereoscopy");
        stereoscopy->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout_7->addWidget(stereoscopy, 5, 1, 1, 1);

        croppingLabel = new QLabel(videoPropertiesBox);
        croppingLabel->setObjectName("croppingLabel");

        gridLayout_7->addWidget(croppingLabel, 3, 0, 1, 1);

        setAspectRatio = new QRadioButton(videoPropertiesBox);
        setAspectRatio->setObjectName("setAspectRatio");

        gridLayout_7->addWidget(setAspectRatio, 0, 0, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setSpacing(6);
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        displayWidth = new QLineEdit(videoPropertiesBox);
        displayWidth->setObjectName("displayWidth");
        displayWidth->setClearButtonEnabled(true);

        horizontalLayout_14->addWidget(displayWidth);

        displayDimensionsXLabel = new QLabel(videoPropertiesBox);
        displayDimensionsXLabel->setObjectName("displayDimensionsXLabel");

        horizontalLayout_14->addWidget(displayDimensionsXLabel);

        displayHeight = new QLineEdit(videoPropertiesBox);
        displayHeight->setObjectName("displayHeight");
        displayHeight->setClearButtonEnabled(true);

        horizontalLayout_14->addWidget(displayHeight);


        gridLayout_7->addLayout(horizontalLayout_14, 1, 1, 1, 1);

        aspectRatio = new QComboBox(videoPropertiesBox);
        aspectRatio->addItem(QString());
        aspectRatio->addItem(QString::fromUtf8("4/3"));
        aspectRatio->addItem(QString::fromUtf8("1.66"));
        aspectRatio->addItem(QString::fromUtf8("16/9"));
        aspectRatio->addItem(QString::fromUtf8("1.85"));
        aspectRatio->addItem(QString::fromUtf8("2.00"));
        aspectRatio->addItem(QString::fromUtf8("2.21"));
        aspectRatio->addItem(QString::fromUtf8("2.35"));
        aspectRatio->addItem(QString::fromUtf8("2.40"));
        aspectRatio->setObjectName("aspectRatio");
        aspectRatio->setEditable(true);

        gridLayout_7->addWidget(aspectRatio, 0, 1, 1, 1);


        verticalLayout_9->addWidget(videoPropertiesBox);

        colorInformationBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        colorInformationBox->setObjectName("colorInformationBox");
        gridLayout_4 = new QGridLayout(colorInformationBox);
        gridLayout_4->setSpacing(6);
        gridLayout_4->setContentsMargins(11, 11, 11, 11);
        gridLayout_4->setObjectName("gridLayout_4");
        transferCharacteristicsLabel = new QLabel(colorInformationBox);
        transferCharacteristicsLabel->setObjectName("transferCharacteristicsLabel");

        gridLayout_4->addWidget(transferCharacteristicsLabel, 6, 0, 1, 1);

        colorRange = new QLineEdit(colorInformationBox);
        colorRange->setObjectName("colorRange");

        gridLayout_4->addWidget(colorRange, 5, 1, 1, 1);

        bitsPerColorChannelLabel = new QLabel(colorInformationBox);
        bitsPerColorChannelLabel->setObjectName("bitsPerColorChannelLabel");

        gridLayout_4->addWidget(bitsPerColorChannelLabel, 1, 0, 1, 1);

        colorPrimariesLabel = new QLabel(colorInformationBox);
        colorPrimariesLabel->setObjectName("colorPrimariesLabel");

        gridLayout_4->addWidget(colorPrimariesLabel, 7, 0, 1, 1);

        cbSubsamplingLabel = new QLabel(colorInformationBox);
        cbSubsamplingLabel->setObjectName("cbSubsamplingLabel");

        gridLayout_4->addWidget(cbSubsamplingLabel, 3, 0, 1, 1);

        chromaSubsampling = new QLineEdit(colorInformationBox);
        chromaSubsampling->setObjectName("chromaSubsampling");

        gridLayout_4->addWidget(chromaSubsampling, 2, 1, 1, 1);

        maximumContentLight = new QLineEdit(colorInformationBox);
        maximumContentLight->setObjectName("maximumContentLight");

        gridLayout_4->addWidget(maximumContentLight, 8, 1, 1, 1);

        maximumContentLightLabel = new QLabel(colorInformationBox);
        maximumContentLightLabel->setObjectName("maximumContentLightLabel");

        gridLayout_4->addWidget(maximumContentLightLabel, 8, 0, 1, 1);

        chromaSiting = new QLineEdit(colorInformationBox);
        chromaSiting->setObjectName("chromaSiting");

        gridLayout_4->addWidget(chromaSiting, 4, 1, 1, 1);

        transferCharacteristics = new QLineEdit(colorInformationBox);
        transferCharacteristics->setObjectName("transferCharacteristics");

        gridLayout_4->addWidget(transferCharacteristics, 6, 1, 1, 1);

        maximumFrameLightLabel = new QLabel(colorInformationBox);
        maximumFrameLightLabel->setObjectName("maximumFrameLightLabel");

        gridLayout_4->addWidget(maximumFrameLightLabel, 9, 0, 1, 1);

        chromaSubsamplingLabel = new QLabel(colorInformationBox);
        chromaSubsamplingLabel->setObjectName("chromaSubsamplingLabel");

        gridLayout_4->addWidget(chromaSubsamplingLabel, 2, 0, 1, 1);

        colorMatrixCoefficientsLabel = new QLabel(colorInformationBox);
        colorMatrixCoefficientsLabel->setObjectName("colorMatrixCoefficientsLabel");

        gridLayout_4->addWidget(colorMatrixCoefficientsLabel, 0, 0, 1, 1);

        bitsPerColorChannel = new QLineEdit(colorInformationBox);
        bitsPerColorChannel->setObjectName("bitsPerColorChannel");

        gridLayout_4->addWidget(bitsPerColorChannel, 1, 1, 1, 1);

        colorPrimaries = new QLineEdit(colorInformationBox);
        colorPrimaries->setObjectName("colorPrimaries");

        gridLayout_4->addWidget(colorPrimaries, 7, 1, 1, 1);

        colorRangeLabel = new QLabel(colorInformationBox);
        colorRangeLabel->setObjectName("colorRangeLabel");

        gridLayout_4->addWidget(colorRangeLabel, 5, 0, 1, 1);

        cbSubsampling = new QLineEdit(colorInformationBox);
        cbSubsampling->setObjectName("cbSubsampling");

        gridLayout_4->addWidget(cbSubsampling, 3, 1, 1, 1);

        colorMatrixCoefficients = new QLineEdit(colorInformationBox);
        colorMatrixCoefficients->setObjectName("colorMatrixCoefficients");

        gridLayout_4->addWidget(colorMatrixCoefficients, 0, 1, 1, 1);

        maximumFrameLight = new QLineEdit(colorInformationBox);
        maximumFrameLight->setObjectName("maximumFrameLight");

        gridLayout_4->addWidget(maximumFrameLight, 9, 1, 1, 1);

        chromaSitingLabel = new QLabel(colorInformationBox);
        chromaSitingLabel->setObjectName("chromaSitingLabel");

        gridLayout_4->addWidget(chromaSitingLabel, 4, 0, 1, 1);


        verticalLayout_9->addWidget(colorInformationBox);

        colorMasteringMetaInformationBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        colorMasteringMetaInformationBox->setObjectName("colorMasteringMetaInformationBox");
        gridLayout_5 = new QGridLayout(colorMasteringMetaInformationBox);
        gridLayout_5->setSpacing(6);
        gridLayout_5->setContentsMargins(11, 11, 11, 11);
        gridLayout_5->setObjectName("gridLayout_5");
        maximumLuminanceLabel = new QLabel(colorMasteringMetaInformationBox);
        maximumLuminanceLabel->setObjectName("maximumLuminanceLabel");

        gridLayout_5->addWidget(maximumLuminanceLabel, 2, 0, 1, 1);

        chromaticityCoordinatesLabel = new QLabel(colorMasteringMetaInformationBox);
        chromaticityCoordinatesLabel->setObjectName("chromaticityCoordinatesLabel");

        gridLayout_5->addWidget(chromaticityCoordinatesLabel, 0, 0, 1, 1);

        whiteColorCoordinates = new QLineEdit(colorMasteringMetaInformationBox);
        whiteColorCoordinates->setObjectName("whiteColorCoordinates");

        gridLayout_5->addWidget(whiteColorCoordinates, 1, 1, 1, 1);

        whiteColorCoordinatesLabel = new QLabel(colorMasteringMetaInformationBox);
        whiteColorCoordinatesLabel->setObjectName("whiteColorCoordinatesLabel");

        gridLayout_5->addWidget(whiteColorCoordinatesLabel, 1, 0, 1, 1);

        minimumLuminanceLabel = new QLabel(colorMasteringMetaInformationBox);
        minimumLuminanceLabel->setObjectName("minimumLuminanceLabel");

        gridLayout_5->addWidget(minimumLuminanceLabel, 3, 0, 1, 1);

        maximumLuminance = new QLineEdit(colorMasteringMetaInformationBox);
        maximumLuminance->setObjectName("maximumLuminance");

        gridLayout_5->addWidget(maximumLuminance, 2, 1, 1, 1);

        minimumLuminance = new QLineEdit(colorMasteringMetaInformationBox);
        minimumLuminance->setObjectName("minimumLuminance");

        gridLayout_5->addWidget(minimumLuminance, 3, 1, 1, 1);

        chromaticityCoordinates = new QLineEdit(colorMasteringMetaInformationBox);
        chromaticityCoordinates->setObjectName("chromaticityCoordinates");

        gridLayout_5->addWidget(chromaticityCoordinates, 0, 1, 1, 1);


        verticalLayout_9->addWidget(colorMasteringMetaInformationBox);

        videoProjectionInformationBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        videoProjectionInformationBox->setObjectName("videoProjectionInformationBox");
        gridLayout_10 = new QGridLayout(videoProjectionInformationBox);
        gridLayout_10->setSpacing(6);
        gridLayout_10->setContentsMargins(11, 11, 11, 11);
        gridLayout_10->setObjectName("gridLayout_10");
        projectionTypeLabel = new QLabel(videoProjectionInformationBox);
        projectionTypeLabel->setObjectName("projectionTypeLabel");

        gridLayout_10->addWidget(projectionTypeLabel, 0, 0, 1, 1);

        projectionSpecificData = new QLineEdit(videoProjectionInformationBox);
        projectionSpecificData->setObjectName("projectionSpecificData");

        gridLayout_10->addWidget(projectionSpecificData, 1, 1, 1, 1);

        yawRotation = new QLineEdit(videoProjectionInformationBox);
        yawRotation->setObjectName("yawRotation");

        gridLayout_10->addWidget(yawRotation, 2, 1, 1, 1);

        pitchRotationLabel = new QLabel(videoProjectionInformationBox);
        pitchRotationLabel->setObjectName("pitchRotationLabel");

        gridLayout_10->addWidget(pitchRotationLabel, 3, 0, 1, 1);

        projectionType = new QLineEdit(videoProjectionInformationBox);
        projectionType->setObjectName("projectionType");

        gridLayout_10->addWidget(projectionType, 0, 1, 1, 1);

        yawRotationLabel = new QLabel(videoProjectionInformationBox);
        yawRotationLabel->setObjectName("yawRotationLabel");

        gridLayout_10->addWidget(yawRotationLabel, 2, 0, 1, 1);

        projectionSpecificDataLabel = new QLabel(videoProjectionInformationBox);
        projectionSpecificDataLabel->setObjectName("projectionSpecificDataLabel");

        gridLayout_10->addWidget(projectionSpecificDataLabel, 1, 0, 1, 1);

        pitchRotation = new QLineEdit(videoProjectionInformationBox);
        pitchRotation->setObjectName("pitchRotation");

        gridLayout_10->addWidget(pitchRotation, 3, 1, 1, 1);

        rollRotationLabel = new QLabel(videoProjectionInformationBox);
        rollRotationLabel->setObjectName("rollRotationLabel");

        gridLayout_10->addWidget(rollRotationLabel, 4, 0, 1, 1);

        rollRotation = new QLineEdit(videoProjectionInformationBox);
        rollRotation->setObjectName("rollRotation");

        gridLayout_10->addWidget(rollRotation, 4, 1, 1, 1);


        verticalLayout_9->addWidget(videoProjectionInformationBox);

        audioPropertiesBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        audioPropertiesBox->setObjectName("audioPropertiesBox");
        verticalLayout_12 = new QVBoxLayout(audioPropertiesBox);
        verticalLayout_12->setSpacing(6);
        verticalLayout_12->setContentsMargins(11, 11, 11, 11);
        verticalLayout_12->setObjectName("verticalLayout_12");
        gridLayout_11 = new QGridLayout();
        gridLayout_11->setSpacing(6);
        gridLayout_11->setObjectName("gridLayout_11");
        aacIsSBRLabel = new QLabel(audioPropertiesBox);
        aacIsSBRLabel->setObjectName("aacIsSBRLabel");

        gridLayout_11->addWidget(aacIsSBRLabel, 0, 0, 1, 1);

        aacIsSBR = new QComboBox(audioPropertiesBox);
        aacIsSBR->setObjectName("aacIsSBR");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(aacIsSBR->sizePolicy().hasHeightForWidth());
        aacIsSBR->setSizePolicy(sizePolicy);

        gridLayout_11->addWidget(aacIsSBR, 0, 1, 1, 1);

        audioEmphasisLabel = new QLabel(audioPropertiesBox);
        audioEmphasisLabel->setObjectName("audioEmphasisLabel");

        gridLayout_11->addWidget(audioEmphasisLabel, 1, 0, 1, 1);

        audioEmphasis = new QComboBox(audioPropertiesBox);
        audioEmphasis->setObjectName("audioEmphasis");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(audioEmphasis->sizePolicy().hasHeightForWidth());
        audioEmphasis->setSizePolicy(sizePolicy1);
        audioEmphasis->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        gridLayout_11->addWidget(audioEmphasis, 1, 1, 1, 1);


        verticalLayout_12->addLayout(gridLayout_11);

        reduceToAudioCore = new QCheckBox(audioPropertiesBox);
        reduceToAudioCore->setObjectName("reduceToAudioCore");

        verticalLayout_12->addWidget(reduceToAudioCore);

        removeDialogNormalizationGain = new QCheckBox(audioPropertiesBox);
        removeDialogNormalizationGain->setObjectName("removeDialogNormalizationGain");

        verticalLayout_12->addWidget(removeDialogNormalizationGain);


        verticalLayout_9->addWidget(audioPropertiesBox);

        subtitleAndChapterPropertiesBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        subtitleAndChapterPropertiesBox->setObjectName("subtitleAndChapterPropertiesBox");
        horizontalLayout_16 = new QHBoxLayout(subtitleAndChapterPropertiesBox);
        horizontalLayout_16->setSpacing(6);
        horizontalLayout_16->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        characterSetLabel = new QLabel(subtitleAndChapterPropertiesBox);
        characterSetLabel->setObjectName("characterSetLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(characterSetLabel->sizePolicy().hasHeightForWidth());
        characterSetLabel->setSizePolicy(sizePolicy2);

        horizontalLayout_16->addWidget(characterSetLabel);

        subtitleCharacterSet = new mtx::gui::Util::CharacterSetComboBox(subtitleAndChapterPropertiesBox);
        subtitleCharacterSet->setObjectName("subtitleCharacterSet");
        sizePolicy.setHeightForWidth(subtitleCharacterSet->sizePolicy().hasHeightForWidth());
        subtitleCharacterSet->setSizePolicy(sizePolicy);
        subtitleCharacterSet->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);

        horizontalLayout_16->addWidget(subtitleCharacterSet);

        subtitleCharacterSetPreview = new QPushButton(subtitleAndChapterPropertiesBox);
        subtitleCharacterSetPreview->setObjectName("subtitleCharacterSetPreview");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("character-set");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        subtitleCharacterSetPreview->setIcon(icon3);

        horizontalLayout_16->addWidget(subtitleCharacterSetPreview);


        verticalLayout_9->addWidget(subtitleAndChapterPropertiesBox);

        miscellaneousBox = new mtx::gui::Util::QgsCollapsibleGroupBox(scrollAreaWidgetContents);
        miscellaneousBox->setObjectName("miscellaneousBox");
        gridLayout_9 = new QGridLayout(miscellaneousBox);
        gridLayout_9->setSpacing(6);
        gridLayout_9->setContentsMargins(11, 11, 11, 11);
        gridLayout_9->setObjectName("gridLayout_9");
        cuesLabel = new QLabel(miscellaneousBox);
        cuesLabel->setObjectName("cuesLabel");

        gridLayout_9->addWidget(cuesLabel, 0, 0, 1, 1);

        cues = new QComboBox(miscellaneousBox);
        cues->setObjectName("cues");

        gridLayout_9->addWidget(cues, 0, 1, 1, 1);

        additionalTrackOptionsLabel = new QLabel(miscellaneousBox);
        additionalTrackOptionsLabel->setObjectName("additionalTrackOptionsLabel");

        gridLayout_9->addWidget(additionalTrackOptionsLabel, 1, 0, 1, 1);

        additionalTrackOptions = new QLineEdit(miscellaneousBox);
        additionalTrackOptions->setObjectName("additionalTrackOptions");
        additionalTrackOptions->setClearButtonEnabled(true);

        gridLayout_9->addWidget(additionalTrackOptions, 1, 1, 1, 1);


        verticalLayout_9->addWidget(miscellaneousBox);

        verticalSpacer_5 = new QSpacerItem(20, 19, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_5);

        propertiesScrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_20->addWidget(propertiesScrollArea);

        propertiesStack->addWidget(propertiesScrollAreaPage);
        propertiesTwoColumnsPage = new QWidget();
        propertiesTwoColumnsPage->setObjectName("propertiesTwoColumnsPage");
        horizontalLayout_17 = new QHBoxLayout(propertiesTwoColumnsPage);
        horizontalLayout_17->setSpacing(6);
        horizontalLayout_17->setContentsMargins(11, 11, 11, 11);
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalLayout_17->setContentsMargins(0, 0, 0, 0);
        propertiesColumn1 = new QWidget(propertiesTwoColumnsPage);
        propertiesColumn1->setObjectName("propertiesColumn1");
        verticalLayout_21 = new QVBoxLayout(propertiesColumn1);
        verticalLayout_21->setSpacing(6);
        verticalLayout_21->setContentsMargins(11, 11, 11, 11);
        verticalLayout_21->setObjectName("verticalLayout_21");
        verticalLayout_21->setContentsMargins(0, 0, 0, 0);
        verticalSpacer_11 = new QSpacerItem(20, 410, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_21->addItem(verticalSpacer_11);


        horizontalLayout_17->addWidget(propertiesColumn1);

        propertiesColumn2 = new QWidget(propertiesTwoColumnsPage);
        propertiesColumn2->setObjectName("propertiesColumn2");
        verticalLayout_22 = new QVBoxLayout(propertiesColumn2);
        verticalLayout_22->setSpacing(6);
        verticalLayout_22->setContentsMargins(11, 11, 11, 11);
        verticalLayout_22->setObjectName("verticalLayout_22");
        verticalLayout_22->setContentsMargins(0, 0, 0, 0);
        verticalSpacer_12 = new QSpacerItem(20, 410, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_22->addItem(verticalSpacer_12);


        horizontalLayout_17->addWidget(propertiesColumn2);

        propertiesStack->addWidget(propertiesTwoColumnsPage);

        verticalLayout_4->addWidget(propertiesStack);

        mergeInputSplitter->addWidget(wProperties);

        horizontalLayout_2->addWidget(mergeInputSplitter);

        tabs->addTab(inputTab, QString());
        outputTab = new QWidget();
        outputTab->setObjectName("outputTab");
        verticalLayout_3 = new QVBoxLayout(outputTab);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        mergeOutputSplitter = new QSplitter(outputTab);
        mergeOutputSplitter->setObjectName("mergeOutputSplitter");
        mergeOutputSplitter->setOrientation(Qt::Horizontal);
        mergeOutputSplitter->setChildrenCollapsible(false);
        layoutWidget4 = new QWidget(mergeOutputSplitter);
        layoutWidget4->setObjectName("layoutWidget4");
        verticalLayout_7 = new QVBoxLayout(layoutWidget4);
        verticalLayout_7->setSpacing(6);
        verticalLayout_7->setContentsMargins(11, 11, 11, 11);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        generalBox = new QGroupBox(layoutWidget4);
        generalBox->setObjectName("generalBox");
        generalGridLayout = new QGridLayout(generalBox);
        generalGridLayout->setSpacing(6);
        generalGridLayout->setContentsMargins(11, 11, 11, 11);
        generalGridLayout->setObjectName("generalGridLayout");
        hlOutput = new QHBoxLayout();
        hlOutput->setSpacing(6);
        hlOutput->setObjectName("hlOutput");
        output = new mtx::gui::Util::BasicLineEdit(generalBox);
        output->setObjectName("output");

        hlOutput->addWidget(output);

        browseOutput = new QPushButton(generalBox);
        browseOutput->setObjectName("browseOutput");
        browseOutput->setIcon(icon2);

        hlOutput->addWidget(browseOutput);

        outputRecentlyUsed = new QPushButton(generalBox);
        outputRecentlyUsed->setObjectName("outputRecentlyUsed");
        outputRecentlyUsed->setText(QString::fromUtf8(""));
        QIcon icon4;
        iconThemeName = QString::fromUtf8("folder-favorites");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        outputRecentlyUsed->setIcon(icon4);

        hlOutput->addWidget(outputRecentlyUsed);


        generalGridLayout->addLayout(hlOutput, 1, 1, 1, 1);

        globalTagsLabel = new QLabel(generalBox);
        globalTagsLabel->setObjectName("globalTagsLabel");

        generalGridLayout->addWidget(globalTagsLabel, 3, 0, 1, 1);

        segmentInfoLabel = new QLabel(generalBox);
        segmentInfoLabel->setObjectName("segmentInfoLabel");

        generalGridLayout->addWidget(segmentInfoLabel, 4, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(6);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        segmentInfo = new mtx::gui::Util::BasicLineEdit(generalBox);
        segmentInfo->setObjectName("segmentInfo");

        horizontalLayout_8->addWidget(segmentInfo);

        browseSegmentInfo = new QPushButton(generalBox);
        browseSegmentInfo->setObjectName("browseSegmentInfo");
        browseSegmentInfo->setIcon(icon2);

        horizontalLayout_8->addWidget(browseSegmentInfo);


        generalGridLayout->addLayout(horizontalLayout_8, 4, 1, 1, 1);

        outputLabel = new QLabel(generalBox);
        outputLabel->setObjectName("outputLabel");

        generalGridLayout->addWidget(outputLabel, 1, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(6);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        globalTags = new mtx::gui::Util::BasicLineEdit(generalBox);
        globalTags->setObjectName("globalTags");

        horizontalLayout_7->addWidget(globalTags);

        browseGlobalTags = new QPushButton(generalBox);
        browseGlobalTags->setObjectName("browseGlobalTags");
        browseGlobalTags->setIcon(icon2);

        horizontalLayout_7->addWidget(browseGlobalTags);


        generalGridLayout->addLayout(horizontalLayout_7, 3, 1, 1, 1);

        titleLael = new QLabel(generalBox);
        titleLael->setObjectName("titleLael");

        generalGridLayout->addWidget(titleLael, 2, 0, 1, 1);

        title = new QLineEdit(generalBox);
        title->setObjectName("title");
        title->setClearButtonEnabled(true);

        generalGridLayout->addWidget(title, 2, 1, 1, 1);


        verticalLayout_7->addWidget(generalBox);

        splittingBox = new QGroupBox(layoutWidget4);
        splittingBox->setObjectName("splittingBox");
        splittingBox->setMinimumSize(QSize(400, 0));
        gridLayout_2 = new QGridLayout(splittingBox);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setContentsMargins(11, 11, 11, 11);
        gridLayout_2->setObjectName("gridLayout_2");
        splitModeLabel = new QLabel(splittingBox);
        splitModeLabel->setObjectName("splitModeLabel");

        gridLayout_2->addWidget(splitModeLabel, 0, 0, 1, 1);

        splitMode = new QComboBox(splittingBox);
        splitMode->setObjectName("splitMode");
        sizePolicy1.setHeightForWidth(splitMode->sizePolicy().hasHeightForWidth());
        splitMode->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(splitMode, 0, 1, 1, 1);

        splitOptions = new QComboBox(splittingBox);
        splitOptions->setObjectName("splitOptions");
        sizePolicy1.setHeightForWidth(splitOptions->sizePolicy().hasHeightForWidth());
        splitOptions->setSizePolicy(sizePolicy1);
        splitOptions->setEditable(true);

        gridLayout_2->addWidget(splitOptions, 1, 1, 1, 1);

        splitMaxFilesLabel = new QLabel(splittingBox);
        splitMaxFilesLabel->setObjectName("splitMaxFilesLabel");

        gridLayout_2->addWidget(splitMaxFilesLabel, 3, 0, 1, 1);

        splitMaxFiles = new mtx::gui::Util::BasicSpinBox(splittingBox);
        splitMaxFiles->setObjectName("splitMaxFiles");
        sizePolicy1.setHeightForWidth(splitMaxFiles->sizePolicy().hasHeightForWidth());
        splitMaxFiles->setSizePolicy(sizePolicy1);
        splitMaxFiles->setMinimum(1);

        gridLayout_2->addWidget(splitMaxFiles, 3, 1, 1, 1);

        linkFiles = new QCheckBox(splittingBox);
        linkFiles->setObjectName("linkFiles");

        gridLayout_2->addWidget(linkFiles, 4, 0, 1, 1);

        splitOptionsLabel = new QLabel(splittingBox);
        splitOptionsLabel->setObjectName("splitOptionsLabel");

        gridLayout_2->addWidget(splitOptionsLabel, 1, 0, 1, 1);


        verticalLayout_7->addWidget(splittingBox);

        outputMischellaneousBox = new QGroupBox(layoutWidget4);
        outputMischellaneousBox->setObjectName("outputMischellaneousBox");
        verticalLayout_6 = new QVBoxLayout(outputMischellaneousBox);
        verticalLayout_6->setSpacing(6);
        verticalLayout_6->setContentsMargins(11, 11, 11, 11);
        verticalLayout_6->setObjectName("verticalLayout_6");
        webmMode = new QCheckBox(outputMischellaneousBox);
        webmMode->setObjectName("webmMode");

        verticalLayout_6->addWidget(webmMode);

        stopAfterVideoEnds = new QCheckBox(outputMischellaneousBox);
        stopAfterVideoEnds->setObjectName("stopAfterVideoEnds");

        verticalLayout_6->addWidget(stopAfterVideoEnds);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setSpacing(6);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        additionalOptionsLabel = new QLabel(outputMischellaneousBox);
        additionalOptionsLabel->setObjectName("additionalOptionsLabel");

        horizontalLayout_10->addWidget(additionalOptionsLabel);

        additionalOptions = new QLineEdit(outputMischellaneousBox);
        additionalOptions->setObjectName("additionalOptions");
        additionalOptions->setClearButtonEnabled(true);

        horizontalLayout_10->addWidget(additionalOptions);

        editAdditionalOptions = new QPushButton(outputMischellaneousBox);
        editAdditionalOptions->setObjectName("editAdditionalOptions");
        QIcon icon5;
        iconThemeName = QString::fromUtf8("view-choose");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        editAdditionalOptions->setIcon(icon5);

        horizontalLayout_10->addWidget(editAdditionalOptions);


        verticalLayout_6->addLayout(horizontalLayout_10);


        verticalLayout_7->addWidget(outputMischellaneousBox);

        verticalSpacer_3 = new QSpacerItem(384, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_7->addItem(verticalSpacer_3);

        mergeOutputSplitter->addWidget(layoutWidget4);
        layoutWidget5 = new QWidget(mergeOutputSplitter);
        layoutWidget5->setObjectName("layoutWidget5");
        verticalLayout_8 = new QVBoxLayout(layoutWidget5);
        verticalLayout_8->setSpacing(6);
        verticalLayout_8->setContentsMargins(11, 11, 11, 11);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        fileSegmentLinkingBox = new QGroupBox(layoutWidget5);
        fileSegmentLinkingBox->setObjectName("fileSegmentLinkingBox");
        gridLayout1 = new QGridLayout(fileSegmentLinkingBox);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName("gridLayout1");
        segmentUIDsLabel = new QLabel(fileSegmentLinkingBox);
        segmentUIDsLabel->setObjectName("segmentUIDsLabel");

        gridLayout1->addWidget(segmentUIDsLabel, 0, 0, 1, 1);

        horizontalLayout_61 = new QHBoxLayout();
        horizontalLayout_61->setSpacing(6);
        horizontalLayout_61->setObjectName("horizontalLayout_61");
        segmentUIDs = new QLineEdit(fileSegmentLinkingBox);
        segmentUIDs->setObjectName("segmentUIDs");
        segmentUIDs->setClearButtonEnabled(true);

        horizontalLayout_61->addWidget(segmentUIDs);

        browseSegmentUID = new QPushButton(fileSegmentLinkingBox);
        browseSegmentUID->setObjectName("browseSegmentUID");
        browseSegmentUID->setIcon(icon2);

        horizontalLayout_61->addWidget(browseSegmentUID);


        gridLayout1->addLayout(horizontalLayout_61, 0, 1, 1, 1);

        previousSegmentUIDLabel = new QLabel(fileSegmentLinkingBox);
        previousSegmentUIDLabel->setObjectName("previousSegmentUIDLabel");

        gridLayout1->addWidget(previousSegmentUIDLabel, 1, 0, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setSpacing(6);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        previousSegmentUID = new QLineEdit(fileSegmentLinkingBox);
        previousSegmentUID->setObjectName("previousSegmentUID");
        previousSegmentUID->setClearButtonEnabled(true);

        horizontalLayout_13->addWidget(previousSegmentUID);

        browsePreviousSegmentUID = new QPushButton(fileSegmentLinkingBox);
        browsePreviousSegmentUID->setObjectName("browsePreviousSegmentUID");
        browsePreviousSegmentUID->setIcon(icon2);

        horizontalLayout_13->addWidget(browsePreviousSegmentUID);


        gridLayout1->addLayout(horizontalLayout_13, 1, 1, 1, 1);

        nextSegmentUIDLabel = new QLabel(fileSegmentLinkingBox);
        nextSegmentUIDLabel->setObjectName("nextSegmentUIDLabel");

        gridLayout1->addWidget(nextSegmentUIDLabel, 2, 0, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setSpacing(6);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        nextSegmentUID = new QLineEdit(fileSegmentLinkingBox);
        nextSegmentUID->setObjectName("nextSegmentUID");
        nextSegmentUID->setClearButtonEnabled(true);

        horizontalLayout_15->addWidget(nextSegmentUID);

        browseNextSegmentUID = new QPushButton(fileSegmentLinkingBox);
        browseNextSegmentUID->setObjectName("browseNextSegmentUID");
        browseNextSegmentUID->setIcon(icon2);

        horizontalLayout_15->addWidget(browseNextSegmentUID);


        gridLayout1->addLayout(horizontalLayout_15, 2, 1, 1, 1);


        verticalLayout_8->addWidget(fileSegmentLinkingBox);

        chaptersBox = new QGroupBox(layoutWidget5);
        chaptersBox->setObjectName("chaptersBox");
        chaptersBox->setMinimumSize(QSize(400, 0));
        gridLayout = new QGridLayout(chaptersBox);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        chapterStretchBy = new QLineEdit(chaptersBox);
        chapterStretchBy->setObjectName("chapterStretchBy");
        chapterStretchBy->setClearButtonEnabled(true);

        gridLayout->addWidget(chapterStretchBy, 6, 1, 1, 1);

        chaptersLabel = new QLabel(chaptersBox);
        chaptersLabel->setObjectName("chaptersLabel");

        gridLayout->addWidget(chaptersLabel, 0, 0, 1, 1);

        chapterGenerationNameTemplateLabel = new QLabel(chaptersBox);
        chapterGenerationNameTemplateLabel->setObjectName("chapterGenerationNameTemplateLabel");

        gridLayout->addWidget(chapterGenerationNameTemplateLabel, 8, 0, 1, 1);

        chapterGenerationIntervalLabel = new QLabel(chaptersBox);
        chapterGenerationIntervalLabel->setObjectName("chapterGenerationIntervalLabel");

        gridLayout->addWidget(chapterGenerationIntervalLabel, 9, 0, 1, 1);

        chapterLanguage = new mtx::gui::Util::LanguageDisplayWidget(chaptersBox);
        chapterLanguage->setObjectName("chapterLanguage");
        chapterLanguage->setFocusPolicy(Qt::TabFocus);

        gridLayout->addWidget(chapterLanguage, 2, 1, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(6);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        chapterCharacterSet = new mtx::gui::Util::CharacterSetComboBox(chaptersBox);
        chapterCharacterSet->setObjectName("chapterCharacterSet");
        sizePolicy.setHeightForWidth(chapterCharacterSet->sizePolicy().hasHeightForWidth());
        chapterCharacterSet->setSizePolicy(sizePolicy);

        horizontalLayout_6->addWidget(chapterCharacterSet);

        chapterCharacterSetPreview = new QPushButton(chaptersBox);
        chapterCharacterSetPreview->setObjectName("chapterCharacterSetPreview");
        chapterCharacterSetPreview->setIcon(icon3);

        horizontalLayout_6->addWidget(chapterCharacterSetPreview);


        gridLayout->addLayout(horizontalLayout_6, 3, 1, 1, 1);

        chapterCueNameFormatLabel = new QLabel(chaptersBox);
        chapterCueNameFormatLabel->setObjectName("chapterCueNameFormatLabel");

        gridLayout->addWidget(chapterCueNameFormatLabel, 4, 0, 1, 1);

        chapterGenerationNameTemplate = new QLineEdit(chaptersBox);
        chapterGenerationNameTemplate->setObjectName("chapterGenerationNameTemplate");
        chapterGenerationNameTemplate->setClearButtonEnabled(true);

        gridLayout->addWidget(chapterGenerationNameTemplate, 8, 1, 1, 1);

        chapterGenerationLabel = new QLabel(chaptersBox);
        chapterGenerationLabel->setObjectName("chapterGenerationLabel");

        gridLayout->addWidget(chapterGenerationLabel, 7, 0, 1, 1);

        chapterStretchByLabel = new QLabel(chaptersBox);
        chapterStretchByLabel->setObjectName("chapterStretchByLabel");

        gridLayout->addWidget(chapterStretchByLabel, 6, 0, 1, 1);

        chapterCueNameFormat = new QLineEdit(chaptersBox);
        chapterCueNameFormat->setObjectName("chapterCueNameFormat");
        chapterCueNameFormat->setClearButtonEnabled(true);

        gridLayout->addWidget(chapterCueNameFormat, 4, 1, 1, 1);

        chapterGenerationMode = new QComboBox(chaptersBox);
        chapterGenerationMode->addItem(QString());
        chapterGenerationMode->addItem(QString());
        chapterGenerationMode->addItem(QString());
        chapterGenerationMode->setObjectName("chapterGenerationMode");

        gridLayout->addWidget(chapterGenerationMode, 7, 1, 1, 1);

        chapterCharacterSetLabel = new QLabel(chaptersBox);
        chapterCharacterSetLabel->setObjectName("chapterCharacterSetLabel");

        gridLayout->addWidget(chapterCharacterSetLabel, 3, 0, 1, 1);

        chapterGenerationInterval = new QLineEdit(chaptersBox);
        chapterGenerationInterval->setObjectName("chapterGenerationInterval");
        chapterGenerationInterval->setClearButtonEnabled(true);

        gridLayout->addWidget(chapterGenerationInterval, 9, 1, 1, 1);

        chapterDelay = new QLineEdit(chaptersBox);
        chapterDelay->setObjectName("chapterDelay");
        chapterDelay->setClearButtonEnabled(true);

        gridLayout->addWidget(chapterDelay, 5, 1, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setSpacing(6);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        chapters = new mtx::gui::Util::BasicLineEdit(chaptersBox);
        chapters->setObjectName("chapters");

        horizontalLayout_9->addWidget(chapters);

        browseChapters = new QPushButton(chaptersBox);
        browseChapters->setObjectName("browseChapters");
        browseChapters->setIcon(icon2);

        horizontalLayout_9->addWidget(browseChapters);


        gridLayout->addLayout(horizontalLayout_9, 0, 1, 1, 1);

        chapterLanguageLabel = new QLabel(chaptersBox);
        chapterLanguageLabel->setObjectName("chapterLanguageLabel");

        gridLayout->addWidget(chapterLanguageLabel, 2, 0, 1, 1);

        chapterDelayLabel = new QLabel(chaptersBox);
        chapterDelayLabel->setObjectName("chapterDelayLabel");

        gridLayout->addWidget(chapterDelayLabel, 5, 0, 1, 1);

        chapterTitleNumberLabel = new QLabel(chaptersBox);
        chapterTitleNumberLabel->setObjectName("chapterTitleNumberLabel");

        gridLayout->addWidget(chapterTitleNumberLabel, 1, 0, 1, 1);

        chapterTitleNumber = new mtx::gui::Util::BasicSpinBox(chaptersBox);
        chapterTitleNumber->setObjectName("chapterTitleNumber");
        chapterTitleNumber->setMinimum(1);

        gridLayout->addWidget(chapterTitleNumber, 1, 1, 1, 1);


        verticalLayout_8->addWidget(chaptersBox);

        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer_4);

        mergeOutputSplitter->addWidget(layoutWidget5);

        verticalLayout_3->addWidget(mergeOutputSplitter);

        tabs->addTab(outputTab, QString());
        attachmentsTab = new mtx::gui::Util::FilesDragDropWidget();
        attachmentsTab->setObjectName("attachmentsTab");
        attachmentsTab->setAcceptDrops(true);
        verticalLayout_24 = new QVBoxLayout(attachmentsTab);
        verticalLayout_24->setSpacing(6);
        verticalLayout_24->setContentsMargins(11, 11, 11, 11);
        verticalLayout_24->setObjectName("verticalLayout_24");
        mergeAttachmentsSplitter = new QSplitter(attachmentsTab);
        mergeAttachmentsSplitter->setObjectName("mergeAttachmentsSplitter");
        mergeAttachmentsSplitter->setOrientation(Qt::Vertical);
        layoutWidget2 = new QWidget(mergeAttachmentsSplitter);
        layoutWidget2->setObjectName("layoutWidget2");
        verticalLayout_23 = new QVBoxLayout(layoutWidget2);
        verticalLayout_23->setSpacing(6);
        verticalLayout_23->setContentsMargins(11, 11, 11, 11);
        verticalLayout_23->setObjectName("verticalLayout_23");
        verticalLayout_23->setContentsMargins(0, 0, 0, 0);
        attachedFilesLabel = new QLabel(layoutWidget2);
        attachedFilesLabel->setObjectName("attachedFilesLabel");

        verticalLayout_23->addWidget(attachedFilesLabel);

        attachedFiles = new mtx::gui::Util::BasicTreeView(layoutWidget2);
        attachedFiles->setObjectName("attachedFiles");
        attachedFiles->setContextMenuPolicy(Qt::CustomContextMenu);
        attachedFiles->setEditTriggers(QAbstractItemView::NoEditTriggers);
        attachedFiles->setProperty("showDropIndicator", QVariant(false));
        attachedFiles->setSelectionMode(QAbstractItemView::ExtendedSelection);
        attachedFiles->setRootIsDecorated(false);
        attachedFiles->setSortingEnabled(true);
        attachedFiles->setAllColumnsShowFocus(true);
        attachedFiles->header()->setProperty("showSortIndicator", QVariant(true));
        attachedFiles->header()->setStretchLastSection(false);

        verticalLayout_23->addWidget(attachedFiles);

        mergeAttachmentsSplitter->addWidget(layoutWidget2);
        layoutWidget3 = new QWidget(mergeAttachmentsSplitter);
        layoutWidget3->setObjectName("layoutWidget3");
        verticalLayout_14 = new QVBoxLayout(layoutWidget3);
        verticalLayout_14->setSpacing(6);
        verticalLayout_14->setContentsMargins(11, 11, 11, 11);
        verticalLayout_14->setObjectName("verticalLayout_14");
        verticalLayout_14->setContentsMargins(0, 0, 0, 0);
        attachmentsLabel = new QLabel(layoutWidget3);
        attachmentsLabel->setObjectName("attachmentsLabel");

        verticalLayout_14->addWidget(attachmentsLabel);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(6);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        attachments = new mtx::gui::Util::BasicTreeView(layoutWidget3);
        attachments->setObjectName("attachments");
        attachments->setContextMenuPolicy(Qt::CustomContextMenu);
        attachments->setAcceptDrops(true);
        attachments->setEditTriggers(QAbstractItemView::NoEditTriggers);
        attachments->setDragEnabled(true);
        attachments->setDragDropMode(QAbstractItemView::DragDrop);
        attachments->setSelectionMode(QAbstractItemView::ExtendedSelection);
        attachments->header()->setStretchLastSection(false);

        horizontalLayout_5->addWidget(attachments);

        moveAttachmentsButtons = new QWidget(layoutWidget3);
        moveAttachmentsButtons->setObjectName("moveAttachmentsButtons");
        verticalLayout_10 = new QVBoxLayout(moveAttachmentsButtons);
        verticalLayout_10->setSpacing(6);
        verticalLayout_10->setContentsMargins(11, 11, 11, 11);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        moveAttachmentsUp = new QPushButton(moveAttachmentsButtons);
        moveAttachmentsUp->setObjectName("moveAttachmentsUp");
        moveAttachmentsUp->setIcon(icon);

        verticalLayout_10->addWidget(moveAttachmentsUp);

        moveAttachmentsDown = new QPushButton(moveAttachmentsButtons);
        moveAttachmentsDown->setObjectName("moveAttachmentsDown");
        moveAttachmentsDown->setIcon(icon1);

        verticalLayout_10->addWidget(moveAttachmentsDown);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_2);


        horizontalLayout_5->addWidget(moveAttachmentsButtons);


        verticalLayout_14->addLayout(horizontalLayout_5);

        mergeAttachmentsSplitter->addWidget(layoutWidget3);

        verticalLayout_24->addWidget(mergeAttachmentsSplitter);

        attachmentSettingsBox = new QGroupBox(attachmentsTab);
        attachmentSettingsBox->setObjectName("attachmentSettingsBox");
        gridLayout_8 = new QGridLayout(attachmentSettingsBox);
        gridLayout_8->setSpacing(6);
        gridLayout_8->setContentsMargins(11, 11, 11, 11);
        gridLayout_8->setObjectName("gridLayout_8");
        attachmentNameLabel = new QLabel(attachmentSettingsBox);
        attachmentNameLabel->setObjectName("attachmentNameLabel");

        gridLayout_8->addWidget(attachmentNameLabel, 0, 0, 1, 1);

        attachmentName = new QLineEdit(attachmentSettingsBox);
        attachmentName->setObjectName("attachmentName");
        attachmentName->setClearButtonEnabled(true);

        gridLayout_8->addWidget(attachmentName, 0, 1, 1, 1);

        attachmentDescriptionLabel = new QLabel(attachmentSettingsBox);
        attachmentDescriptionLabel->setObjectName("attachmentDescriptionLabel");

        gridLayout_8->addWidget(attachmentDescriptionLabel, 0, 2, 1, 1);

        attachmentDescription = new QLineEdit(attachmentSettingsBox);
        attachmentDescription->setObjectName("attachmentDescription");
        attachmentDescription->setClearButtonEnabled(true);

        gridLayout_8->addWidget(attachmentDescription, 0, 3, 1, 1);

        attachmentMIMETypeLabel = new QLabel(attachmentSettingsBox);
        attachmentMIMETypeLabel->setObjectName("attachmentMIMETypeLabel");

        gridLayout_8->addWidget(attachmentMIMETypeLabel, 1, 0, 1, 1);

        attachmentMIMEType = new QComboBox(attachmentSettingsBox);
        attachmentMIMEType->setObjectName("attachmentMIMEType");
        attachmentMIMEType->setEditable(true);

        gridLayout_8->addWidget(attachmentMIMEType, 1, 1, 1, 1);

        attachmentStyleLabel = new QLabel(attachmentSettingsBox);
        attachmentStyleLabel->setObjectName("attachmentStyleLabel");

        gridLayout_8->addWidget(attachmentStyleLabel, 1, 2, 1, 1);

        attachmentStyle = new QComboBox(attachmentSettingsBox);
        attachmentStyle->addItem(QString());
        attachmentStyle->addItem(QString());
        attachmentStyle->setObjectName("attachmentStyle");

        gridLayout_8->addWidget(attachmentStyle, 1, 3, 1, 1);


        verticalLayout_24->addWidget(attachmentSettingsBox);

        tabs->addTab(attachmentsTab, QString());

        verticalLayout_2->addWidget(tabs);

        gbOutputFile = new QGroupBox(mtx__gui__Merge__Tab);
        gbOutputFile->setObjectName("gbOutputFile");

        verticalLayout_2->addWidget(gbOutputFile);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        addFiles = new QToolButton(mtx__gui__Merge__Tab);
        addFiles->setObjectName("addFiles");
        QIcon icon6;
        iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addFiles->setIcon(icon6);
        addFiles->setPopupMode(QToolButton::MenuButtonPopup);
        addFiles->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(addFiles);

        startMuxing = new QToolButton(mtx__gui__Merge__Tab);
        startMuxing->setObjectName("startMuxing");
        QIcon icon7;
        iconThemeName = QString::fromUtf8("media-playback-start");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        startMuxing->setIcon(icon7);
        startMuxing->setPopupMode(QToolButton::MenuButtonPopup);
        startMuxing->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(startMuxing);

        addToJobQueue = new QToolButton(mtx__gui__Merge__Tab);
        addToJobQueue->setObjectName("addToJobQueue");
        QIcon icon8;
        iconThemeName = QString::fromUtf8("task-delegate");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon8 = QIcon::fromTheme(iconThemeName);
        } else {
            icon8.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addToJobQueue->setIcon(icon8);
        addToJobQueue->setPopupMode(QToolButton::MenuButtonPopup);
        addToJobQueue->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(addToJobQueue);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout_2->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        filesLabel->setBuddy(files);
        tracksLabel->setBuddy(tracks);
        forcedTrackFlagLabel->setBuddy(forcedTrackFlag);
        muxThisLabel->setBuddy(muxThis);
        trackLanguageLabel->setBuddy(trackLanguage);
        trackNameLabel->setBuddy(trackName);
        titleLael->setBuddy(title);
        attachedFilesLabel->setBuddy(attachedFiles);
        attachmentsLabel->setBuddy(attachments);
        attachmentNameLabel->setBuddy(attachmentName);
        attachmentDescriptionLabel->setBuddy(attachmentDescription);
        attachmentMIMETypeLabel->setBuddy(attachmentMIMEType);
        attachmentStyleLabel->setBuddy(attachmentStyle);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(files, moveFilesUp);
        QWidget::setTabOrder(moveFilesUp, moveFilesDown);
        QWidget::setTabOrder(moveFilesDown, tracks);
        QWidget::setTabOrder(tracks, moveTracksUp);
        QWidget::setTabOrder(moveTracksUp, moveTracksDown);
        QWidget::setTabOrder(moveTracksDown, videoProjectionInformationPage);
        QWidget::setTabOrder(videoProjectionInformationPage, propertiesScrollArea);
        QWidget::setTabOrder(propertiesScrollArea, muxThis);
        QWidget::setTabOrder(muxThis, trackName);
        QWidget::setTabOrder(trackName, trackLanguage);
        QWidget::setTabOrder(trackLanguage, defaultTrackFlag);
        QWidget::setTabOrder(defaultTrackFlag, trackEnabledFlag);
        QWidget::setTabOrder(trackEnabledFlag, forcedTrackFlag);
        QWidget::setTabOrder(forcedTrackFlag, hearingImpairedFlag);
        QWidget::setTabOrder(hearingImpairedFlag, visualImpairedFlag);
        QWidget::setTabOrder(visualImpairedFlag, textDescriptionsFlag);
        QWidget::setTabOrder(textDescriptionsFlag, originalFlag);
        QWidget::setTabOrder(originalFlag, commentaryFlag);
        QWidget::setTabOrder(commentaryFlag, compression);
        QWidget::setTabOrder(compression, trackTags);
        QWidget::setTabOrder(trackTags, browseTrackTags);
        QWidget::setTabOrder(browseTrackTags, delay);
        QWidget::setTabOrder(delay, stretchBy);
        QWidget::setTabOrder(stretchBy, defaultDuration);
        QWidget::setTabOrder(defaultDuration, timestamps);
        QWidget::setTabOrder(timestamps, browseTimestamps);
        QWidget::setTabOrder(browseTimestamps, fixBitstreamTimingInfo);
        QWidget::setTabOrder(fixBitstreamTimingInfo, setAspectRatio);
        QWidget::setTabOrder(setAspectRatio, aspectRatio);
        QWidget::setTabOrder(aspectRatio, setDisplayWidthHeight);
        QWidget::setTabOrder(setDisplayWidthHeight, displayWidth);
        QWidget::setTabOrder(displayWidth, displayHeight);
        QWidget::setTabOrder(displayHeight, cropping);
        QWidget::setTabOrder(cropping, stereoscopy);
        QWidget::setTabOrder(stereoscopy, colorMatrixCoefficients);
        QWidget::setTabOrder(colorMatrixCoefficients, bitsPerColorChannel);
        QWidget::setTabOrder(bitsPerColorChannel, chromaSubsampling);
        QWidget::setTabOrder(chromaSubsampling, cbSubsampling);
        QWidget::setTabOrder(cbSubsampling, chromaSiting);
        QWidget::setTabOrder(chromaSiting, colorRange);
        QWidget::setTabOrder(colorRange, transferCharacteristics);
        QWidget::setTabOrder(transferCharacteristics, colorPrimaries);
        QWidget::setTabOrder(colorPrimaries, maximumContentLight);
        QWidget::setTabOrder(maximumContentLight, maximumFrameLight);
        QWidget::setTabOrder(maximumFrameLight, chromaticityCoordinates);
        QWidget::setTabOrder(chromaticityCoordinates, whiteColorCoordinates);
        QWidget::setTabOrder(whiteColorCoordinates, maximumLuminance);
        QWidget::setTabOrder(maximumLuminance, minimumLuminance);
        QWidget::setTabOrder(minimumLuminance, projectionType);
        QWidget::setTabOrder(projectionType, projectionSpecificData);
        QWidget::setTabOrder(projectionSpecificData, yawRotation);
        QWidget::setTabOrder(yawRotation, pitchRotation);
        QWidget::setTabOrder(pitchRotation, rollRotation);
        QWidget::setTabOrder(rollRotation, aacIsSBR);
        QWidget::setTabOrder(aacIsSBR, audioEmphasis);
        QWidget::setTabOrder(audioEmphasis, reduceToAudioCore);
        QWidget::setTabOrder(reduceToAudioCore, removeDialogNormalizationGain);
        QWidget::setTabOrder(removeDialogNormalizationGain, subtitleCharacterSet);
        QWidget::setTabOrder(subtitleCharacterSet, subtitleCharacterSetPreview);
        QWidget::setTabOrder(subtitleCharacterSetPreview, cues);
        QWidget::setTabOrder(cues, additionalTrackOptions);
        QWidget::setTabOrder(additionalTrackOptions, output);
        QWidget::setTabOrder(output, browseOutput);
        QWidget::setTabOrder(browseOutput, outputRecentlyUsed);
        QWidget::setTabOrder(outputRecentlyUsed, title);
        QWidget::setTabOrder(title, globalTags);
        QWidget::setTabOrder(globalTags, browseGlobalTags);
        QWidget::setTabOrder(browseGlobalTags, segmentInfo);
        QWidget::setTabOrder(segmentInfo, browseSegmentInfo);
        QWidget::setTabOrder(browseSegmentInfo, splitMode);
        QWidget::setTabOrder(splitMode, splitOptions);
        QWidget::setTabOrder(splitOptions, splitMaxFiles);
        QWidget::setTabOrder(splitMaxFiles, linkFiles);
        QWidget::setTabOrder(linkFiles, webmMode);
        QWidget::setTabOrder(webmMode, stopAfterVideoEnds);
        QWidget::setTabOrder(stopAfterVideoEnds, additionalOptions);
        QWidget::setTabOrder(additionalOptions, editAdditionalOptions);
        QWidget::setTabOrder(editAdditionalOptions, segmentUIDs);
        QWidget::setTabOrder(segmentUIDs, browseSegmentUID);
        QWidget::setTabOrder(browseSegmentUID, previousSegmentUID);
        QWidget::setTabOrder(previousSegmentUID, browsePreviousSegmentUID);
        QWidget::setTabOrder(browsePreviousSegmentUID, nextSegmentUID);
        QWidget::setTabOrder(nextSegmentUID, browseNextSegmentUID);
        QWidget::setTabOrder(browseNextSegmentUID, chapters);
        QWidget::setTabOrder(chapters, browseChapters);
        QWidget::setTabOrder(browseChapters, chapterTitleNumber);
        QWidget::setTabOrder(chapterTitleNumber, chapterLanguage);
        QWidget::setTabOrder(chapterLanguage, chapterCharacterSet);
        QWidget::setTabOrder(chapterCharacterSet, chapterCharacterSetPreview);
        QWidget::setTabOrder(chapterCharacterSetPreview, chapterCueNameFormat);
        QWidget::setTabOrder(chapterCueNameFormat, chapterDelay);
        QWidget::setTabOrder(chapterDelay, chapterStretchBy);
        QWidget::setTabOrder(chapterStretchBy, chapterGenerationMode);
        QWidget::setTabOrder(chapterGenerationMode, chapterGenerationNameTemplate);
        QWidget::setTabOrder(chapterGenerationNameTemplate, chapterGenerationInterval);
        QWidget::setTabOrder(chapterGenerationInterval, attachedFilesLabel);
        QWidget::setTabOrder(attachedFilesLabel, attachedFiles);
        QWidget::setTabOrder(attachedFiles, attachmentsLabel);
        QWidget::setTabOrder(attachmentsLabel, attachments);
        QWidget::setTabOrder(attachments, moveAttachmentsUp);
        QWidget::setTabOrder(moveAttachmentsUp, moveAttachmentsDown);
        QWidget::setTabOrder(moveAttachmentsDown, attachmentName);
        QWidget::setTabOrder(attachmentName, attachmentDescription);
        QWidget::setTabOrder(attachmentDescription, attachmentMIMEType);
        QWidget::setTabOrder(attachmentMIMEType, attachmentStyle);
        QWidget::setTabOrder(attachmentStyle, addFiles);
        QWidget::setTabOrder(addFiles, startMuxing);
        QWidget::setTabOrder(startMuxing, addToJobQueue);

        retranslateUi(mtx__gui__Merge__Tab);

        tabs->setCurrentIndex(0);
        twProperties->setCurrentIndex(0);
        propertiesStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(mtx__gui__Merge__Tab);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Merge__Tab)
    {
        filesLabel->setText(QTR("Source &files:", nullptr));
        moveFilesUp->setText(QString());
        moveFilesDown->setText(QString());
        tracksLabel->setText(QTR("&Tracks, chapters and tags:", nullptr));
        moveTracksUp->setText(QString());
        moveTracksDown->setText(QString());
        twProperties->setTabText(twProperties->indexOf(generalOptionsPage), QTR("General options", nullptr));
        twProperties->setTabText(twProperties->indexOf(timestampsAndDefaultDurationPage), QTR("Timestamps and default duration", nullptr));
        twProperties->setTabText(twProperties->indexOf(videoPropertiesPage), QTR("Video properties", nullptr));
        twProperties->setTabText(twProperties->indexOf(colorInformationPage), QTR("Color information", nullptr));
        twProperties->setTabText(twProperties->indexOf(colorMasteringMetaInformationPage), QTR("Color mastering meta information", nullptr));
        twProperties->setTabText(twProperties->indexOf(videoProjectionInformationPage), QTR("Video projection information", nullptr));
        twProperties->setTabText(twProperties->indexOf(audioSubtitleChapterPropertiesPage), QTR("Audio, subtitle, chapter properties", nullptr));
        twProperties->setTabText(twProperties->indexOf(miscellaneousPage), QTR("Miscellaneous", nullptr));
        propertiesLabel->setText(QTR("Properties:", nullptr));
        generalOptionsBox->setTitle(QTR("General options", nullptr));
        defaultTrackFlagLabel->setText(QTR("\"Default track\" flag:", nullptr));
        textDescriptionsFlagLabel->setText(QTR("\"Text descriptions\" flag:", nullptr));
        forcedTrackFlagLabel->setText(QTR("\"Forced display\" flag:", nullptr));
        muxThisLabel->setText(QTR("Cop&y this item:", nullptr));
        hearingImpairedFlagLabel->setText(QTR("\"Hearing impaired\" flag:", nullptr));
        trackLanguageLabel->setText(QTR("&Language:", nullptr));
        visualImpairedFlagLabel->setText(QTR("\"Visual impaired\" flag:", nullptr));
        originalFlagLabel->setText(QTR("\"Original language\" flag:", nullptr));
        browseTrackTags->setText(QString());
        trackNameLabel->setText(QTR("Trac&k name:", nullptr));
        trackTagsLabel->setText(QTR("Tags:", nullptr));
        compressionLabel->setText(QTR("Compression:", nullptr));
        commentaryFlagLabel->setText(QTR("\"Commentary\" flag:", nullptr));
        trackEnabledFlagLabel->setText(QTR("\"Track enabled\" flag:", nullptr));
        timestampsAndDefaultDurationBox->setTitle(QTR("Timestamps and default duration", nullptr));
        delayLabel->setText(QTR("Delay (in ms):", nullptr));
        stretchByLabel->setText(QTR("Stretch by:", nullptr));
        defaultDurationLabel->setText(QTR("Default duration/FPS:", nullptr));

        timestampsLabel->setText(QTR("Timestamp file:", nullptr));
        browseTimestamps->setText(QString());
        fixBitstreamTimingInfo->setText(QTR("Fix bitstream timing info", nullptr));
        videoPropertiesBox->setTitle(QTR("Video properties", nullptr));
        setDisplayWidthHeight->setText(QTR("Display width/height:", nullptr));
        stereoscopyLabel->setText(QTR("Stereoscopy:", nullptr));
        croppingLabel->setText(QTR("Cropping:", nullptr));
        setAspectRatio->setText(QTR("Set aspect ratio:", nullptr));
        displayDimensionsXLabel->setText(QTR("x", nullptr));
        aspectRatio->setItemText(0, QString());

        colorInformationBox->setTitle(QTR("Color information", nullptr));
        transferCharacteristicsLabel->setText(QTR("Transfer characteristics:", nullptr));
        bitsPerColorChannelLabel->setText(QTR("Bits per color channel:", nullptr));
        colorPrimariesLabel->setText(QTR("Color primaries:", nullptr));
        cbSubsamplingLabel->setText(QTR("Cb subsampling:", nullptr));
        maximumContentLightLabel->setText(QTR("Maximum content light:", nullptr));
        maximumFrameLightLabel->setText(QTR("Maximum frame light:", nullptr));
        chromaSubsamplingLabel->setText(QTR("Chroma subsampling:", nullptr));
        colorMatrixCoefficientsLabel->setText(QTR("Color matrix coefficients:", nullptr));
        colorRangeLabel->setText(QTR("Color range:", nullptr));
        chromaSitingLabel->setText(QTR("Chroma siting:", nullptr));
        colorMasteringMetaInformationBox->setTitle(QTR("Color mastering meta information", nullptr));
        maximumLuminanceLabel->setText(QTR("Maximum luminance:", nullptr));
        chromaticityCoordinatesLabel->setText(QTR("Chromaticity coordinates:", nullptr));
        whiteColorCoordinatesLabel->setText(QTR("White color coordinates:", nullptr));
        minimumLuminanceLabel->setText(QTR("Minimum luminance:", nullptr));
        videoProjectionInformationBox->setTitle(QTR("Video projection information", nullptr));
        projectionTypeLabel->setText(QTR("Projection type:", nullptr));
        pitchRotationLabel->setText(QTR("Pitch rotation:", nullptr));
        yawRotationLabel->setText(QTR("Yaw rotation:", nullptr));
        projectionSpecificDataLabel->setText(QTR("Projection-specific data:", nullptr));
        rollRotationLabel->setText(QTR("Roll rotation:", nullptr));
        audioPropertiesBox->setTitle(QTR("Audio properties", nullptr));
        aacIsSBRLabel->setText(QTR("AAC is SBR/HE-AAC/AAC+:", nullptr));
        audioEmphasisLabel->setText(QTR("Emphasis:", nullptr));
        reduceToAudioCore->setText(QTR("Reduce to core", nullptr));
        removeDialogNormalizationGain->setText(QTR("Remove dialog normalization gain", nullptr));
        subtitleAndChapterPropertiesBox->setTitle(QTR("Subtitle and chapter properties", nullptr));
        characterSetLabel->setText(QTR("Character set:", nullptr));
        subtitleCharacterSetPreview->setText(QString());
        miscellaneousBox->setTitle(QTR("Miscellaneous", nullptr));
        cuesLabel->setText(QTR("Indexing (cues):", nullptr));
        additionalTrackOptionsLabel->setText(QTR("Additional options:", nullptr));
        tabs->setTabText(tabs->indexOf(inputTab), QTR("&Input", nullptr));
        generalBox->setTitle(QTR("General", nullptr));
        browseOutput->setText(QString());
        globalTagsLabel->setText(QTR("Global tags:", nullptr));
        segmentInfoLabel->setText(QTR("Segment info:", nullptr));
        browseSegmentInfo->setText(QString());
        outputLabel->setText(QTR("Destination file:", nullptr));
        browseGlobalTags->setText(QString());
        titleLael->setText(QTR("Fi&le title:", nullptr));
        splittingBox->setTitle(QTR("Splitting", nullptr));
        splitModeLabel->setText(QTR("Split mode:", nullptr));
        splitMaxFilesLabel->setText(QTR("Maximum number of files:", nullptr));
        splitMaxFiles->setSpecialValueText(QTR("Unlimited", nullptr));
        linkFiles->setText(QTR("Link files", nullptr));
        splitOptionsLabel->setText(QTR("Options:", nullptr));
        outputMischellaneousBox->setTitle(QTR("Miscellaneous", nullptr));
        webmMode->setText(QTR("Create WebM compliant file", nullptr));
        stopAfterVideoEnds->setText(QTR("Stop after video track ends", nullptr));
        additionalOptionsLabel->setText(QTR("Additional options:", nullptr));
        editAdditionalOptions->setText(QString());
        fileSegmentLinkingBox->setTitle(QTR("File/Segment linking", nullptr));
        segmentUIDsLabel->setText(QTR("Segment UIDs:", nullptr));
        browseSegmentUID->setText(QString());
        previousSegmentUIDLabel->setText(QTR("Previous segment UID:", nullptr));
        browsePreviousSegmentUID->setText(QString());
        nextSegmentUIDLabel->setText(QTR("Next segment UID:", nullptr));
        browseNextSegmentUID->setText(QString());
        chaptersBox->setTitle(QTR("Chapters", nullptr));
        chaptersLabel->setText(QTR("Chapter file:", nullptr));
        chapterGenerationNameTemplateLabel->setText(QTR("Name template:", nullptr));
        chapterGenerationIntervalLabel->setText(QTR("Interval:", nullptr));
        chapterCharacterSetPreview->setText(QString());
        chapterCueNameFormatLabel->setText(QTR("Cue name format:", nullptr));
        chapterGenerationLabel->setText(QTR("Generating chapters:", nullptr));
        chapterStretchByLabel->setText(QTR("Stretch by:", nullptr));
        chapterGenerationMode->setItemText(0, QTR("Don't generate chapters", nullptr));
        chapterGenerationMode->setItemText(1, QTR("One chapter for each appended file", nullptr));
        chapterGenerationMode->setItemText(2, QTR("Chapters in fixed intervals", nullptr));

        chapterCharacterSetLabel->setText(QTR("Character set:", nullptr));
        browseChapters->setText(QString());
        chapterLanguageLabel->setText(QTR("Language:", nullptr));
        chapterDelayLabel->setText(QTR("Delay (in ms):", nullptr));
        chapterTitleNumberLabel->setText(QTR("DVD title number:", nullptr));
        tabs->setTabText(tabs->indexOf(outputTab), QTR("&Output", nullptr));
        attachedFilesLabel->setText(QTR("Attachments from &source files:", nullptr));
        attachmentsLabel->setText(QTR("Atta&chments to add:", nullptr));
        moveAttachmentsUp->setText(QString());
        moveAttachmentsDown->setText(QString());
        attachmentSettingsBox->setTitle(QTR("Settings", nullptr));
        attachmentNameLabel->setText(QTR("&Name:", nullptr));
        attachmentDescriptionLabel->setText(QTR("&Description:", nullptr));
        attachmentMIMETypeLabel->setText(QTR("&MIME type:", nullptr));
        attachmentStyleLabel->setText(QTR("Attach &to:", nullptr));
        attachmentStyle->setItemText(0, QTR("All destination files", nullptr));
        attachmentStyle->setItemText(1, QTR("The first destination file only", nullptr));

        tabs->setTabText(tabs->indexOf(attachmentsTab), QTR("Atta&chments", nullptr));
        gbOutputFile->setTitle(QTR("Destination file", nullptr));
        addFiles->setText(QTR("&Add source files", nullptr));
        startMuxing->setText(QTR("Sta&rt multiplexing", nullptr));
        addToJobQueue->setText(QTR("Add to job &queue", nullptr));
        (void)mtx__gui__Merge__Tab;
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class Tab: public Ui_Tab {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // TAB_H
