/********************************************************************************
** Form generated from reading UI file 'language_display_widget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef LANGUAGE_DISPLAY_WIDGET_H
#define LANGUAGE_DISPLAY_WIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/elide_label.h"

namespace mtx {
namespace gui {
namespace Util {

class Ui_LanguageDisplayWidget
{
public:
    QHBoxLayout *horizontalLayout;
    mtx::gui::Util::ElideLabel *lLanguage;
    QPushButton *pbClear;
    QPushButton *pbEdit;

    void setupUi(QWidget *mtx__gui__Util__LanguageDisplayWidget)
    {
        if (mtx__gui__Util__LanguageDisplayWidget->objectName().isEmpty())
            mtx__gui__Util__LanguageDisplayWidget->setObjectName("mtx__gui__Util__LanguageDisplayWidget");
        mtx__gui__Util__LanguageDisplayWidget->resize(400, 24);
        mtx__gui__Util__LanguageDisplayWidget->setWindowTitle(QString::fromUtf8(""));
        horizontalLayout = new QHBoxLayout(mtx__gui__Util__LanguageDisplayWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        lLanguage = new mtx::gui::Util::ElideLabel(mtx__gui__Util__LanguageDisplayWidget);
        lLanguage->setObjectName("lLanguage");
        lLanguage->setFrameShape(QFrame::NoFrame);
        lLanguage->setFrameShadow(QFrame::Plain);

        horizontalLayout->addWidget(lLanguage, 0, Qt::AlignVCenter);

        pbClear = new QPushButton(mtx__gui__Util__LanguageDisplayWidget);
        pbClear->setObjectName("pbClear");
        pbClear->setText(QString::fromUtf8(""));
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        pbClear->setIcon(icon);

        horizontalLayout->addWidget(pbClear, 0, Qt::AlignVCenter);

        pbEdit = new QPushButton(mtx__gui__Util__LanguageDisplayWidget);
        pbEdit->setObjectName("pbEdit");
        pbEdit->setText(QString::fromUtf8(""));
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-entry")));
        pbEdit->setIcon(icon1);

        horizontalLayout->addWidget(pbEdit, 0, Qt::AlignVCenter);

        horizontalLayout->setStretch(0, 1);

        retranslateUi(mtx__gui__Util__LanguageDisplayWidget);

        QMetaObject::connectSlotsByName(mtx__gui__Util__LanguageDisplayWidget);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Util__LanguageDisplayWidget)
    {
        (void)mtx__gui__Util__LanguageDisplayWidget;
    } // retranslateUi

};

} // namespace Util
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Util {
namespace Ui {
    class LanguageDisplayWidget: public Ui_LanguageDisplayWidget {};
} // namespace Ui
} // namespace Util
} // namespace gui
} // namespace mtx

#endif // LANGUAGE_DISPLAY_WIDGET_H
