/********************************************************************************
** Form generated from reading UI file 'command_line_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef COMMAND_LINE_DIALOG_H
#define COMMAND_LINE_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace mtx {
namespace gui {
namespace Merge {

class Ui_CommandLineDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QComboBox *multiplexSettings;
    QLabel *label;
    QComboBox *escapeMode;
    QPlainTextEdit *commandLine;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pbCopyToClipboard;
    QPushButton *pbClose;

    void setupUi(QDialog *mtx__gui__Merge__CommandLineDialog)
    {
        if (mtx__gui__Merge__CommandLineDialog->objectName().isEmpty())
            mtx__gui__Merge__CommandLineDialog->setObjectName("mtx__gui__Merge__CommandLineDialog");
        mtx__gui__Merge__CommandLineDialog->resize(550, 295);
        verticalLayout = new QVBoxLayout(mtx__gui__Merge__CommandLineDialog);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(mtx__gui__Merge__CommandLineDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        multiplexSettings = new QComboBox(mtx__gui__Merge__CommandLineDialog);
        multiplexSettings->setObjectName("multiplexSettings");

        gridLayout->addWidget(multiplexSettings, 0, 1, 1, 1);

        label = new QLabel(mtx__gui__Merge__CommandLineDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        escapeMode = new QComboBox(mtx__gui__Merge__CommandLineDialog);
        escapeMode->setObjectName("escapeMode");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(escapeMode->sizePolicy().hasHeightForWidth());
        escapeMode->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(escapeMode, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        commandLine = new QPlainTextEdit(mtx__gui__Merge__CommandLineDialog);
        commandLine->setObjectName("commandLine");
        commandLine->setUndoRedoEnabled(false);
        commandLine->setReadOnly(true);
        commandLine->setPlainText(QString::fromUtf8(""));
        commandLine->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        verticalLayout->addWidget(commandLine);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pbCopyToClipboard = new QPushButton(mtx__gui__Merge__CommandLineDialog);
        pbCopyToClipboard->setObjectName("pbCopyToClipboard");

        horizontalLayout_2->addWidget(pbCopyToClipboard);

        pbClose = new QPushButton(mtx__gui__Merge__CommandLineDialog);
        pbClose->setObjectName("pbClose");

        horizontalLayout_2->addWidget(pbClose);


        verticalLayout->addLayout(horizontalLayout_2);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(multiplexSettings);
        label->setBuddy(escapeMode);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(multiplexSettings, escapeMode);
        QWidget::setTabOrder(escapeMode, commandLine);
        QWidget::setTabOrder(commandLine, pbCopyToClipboard);
        QWidget::setTabOrder(pbCopyToClipboard, pbClose);

        retranslateUi(mtx__gui__Merge__CommandLineDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Merge__CommandLineDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__CommandLineDialog)
    {
        mtx__gui__Merge__CommandLineDialog->setWindowTitle(QTR("Current command line", nullptr));
        label_2->setText(QTR("Multiplex &settings:", nullptr));
        label->setText(QTR("&Escape arguments for:", nullptr));
        pbCopyToClipboard->setText(QTR("C&opy to clipboard", nullptr));
        pbClose->setText(QTR("&Close", nullptr));
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class CommandLineDialog: public Ui_CommandLineDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // COMMAND_LINE_DIALOG_H
