/********************************************************************************
** Form generated from reading UI file 'prefs_language_shortcut_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef PREFS_LANGUAGE_SHORTCUT_DIALOG_H
#define PREFS_LANGUAGE_SHORTCUT_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/util/language_display_widget.h"

namespace mtx {
namespace gui {

class Ui_PrefsLanguageShortcutDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lTitle;
    QFrame *line;
    QGridLayout *gridLayout;
    QLabel *label_2;
    mtx::gui::Util::LanguageDisplayWidget *ldwLanguage;
    QLabel *label_3;
    QLineEdit *leTrackName;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttons;

    void setupUi(QDialog *mtx__gui__PrefsLanguageShortcutDialog)
    {
        if (mtx__gui__PrefsLanguageShortcutDialog->objectName().isEmpty())
            mtx__gui__PrefsLanguageShortcutDialog->setObjectName("mtx__gui__PrefsLanguageShortcutDialog");
        mtx__gui__PrefsLanguageShortcutDialog->resize(490, 141);
        mtx__gui__PrefsLanguageShortcutDialog->setWindowTitle(QString::fromUtf8("Dialog"));
        verticalLayout = new QVBoxLayout(mtx__gui__PrefsLanguageShortcutDialog);
        verticalLayout->setObjectName("verticalLayout");
        lTitle = new QLabel(mtx__gui__PrefsLanguageShortcutDialog);
        lTitle->setObjectName("lTitle");
        lTitle->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(lTitle);

        line = new QFrame(mtx__gui__PrefsLanguageShortcutDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(mtx__gui__PrefsLanguageShortcutDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        ldwLanguage = new mtx::gui::Util::LanguageDisplayWidget(mtx__gui__PrefsLanguageShortcutDialog);
        ldwLanguage->setObjectName("ldwLanguage");
        ldwLanguage->setFocusPolicy(Qt::TabFocus);

        gridLayout->addWidget(ldwLanguage, 0, 1, 1, 1);

        label_3 = new QLabel(mtx__gui__PrefsLanguageShortcutDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        leTrackName = new QLineEdit(mtx__gui__PrefsLanguageShortcutDialog);
        leTrackName->setObjectName("leTrackName");

        gridLayout->addWidget(leTrackName, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttons = new QDialogButtonBox(mtx__gui__PrefsLanguageShortcutDialog);
        buttons->setObjectName("buttons");
        buttons->setOrientation(Qt::Horizontal);
        buttons->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttons);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(ldwLanguage);
        label_3->setBuddy(leTrackName);
#endif // QT_CONFIG(shortcut)

        retranslateUi(mtx__gui__PrefsLanguageShortcutDialog);
        QObject::connect(buttons, &QDialogButtonBox::accepted, mtx__gui__PrefsLanguageShortcutDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttons, &QDialogButtonBox::rejected, mtx__gui__PrefsLanguageShortcutDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(mtx__gui__PrefsLanguageShortcutDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__PrefsLanguageShortcutDialog)
    {
        label_2->setText(QTR("&Language:", nullptr));
        label_3->setText(QTR("Track &name (optional):", nullptr));
        leTrackName->setText(QString());
        (void)mtx__gui__PrefsLanguageShortcutDialog;
    } // retranslateUi

};

} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Ui {
    class PrefsLanguageShortcutDialog: public Ui_PrefsLanguageShortcutDialog {};
} // namespace Ui
} // namespace gui
} // namespace mtx

#endif // PREFS_LANGUAGE_SHORTCUT_DIALOG_H
