/********************************************************************************
** Form generated from reading UI file 'mass_modification_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef MASS_MODIFICATION_DIALOG_H
#define MASS_MODIFICATION_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/util/language_display_widget.h"

namespace mtx {
namespace gui {
namespace ChapterEditor {

class Ui_MassModificationDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *lTitle;
    QFrame *line;
    QGridLayout *gridLayout;
    QCheckBox *cbShift;
    QDoubleSpinBox *dsbMultiplyBy;
    mtx::gui::Util::LanguageDisplayWidget *ldwLanguage;
    QCheckBox *cbSetLanguage;
    QLineEdit *leShiftBy;
    QCheckBox *cbMultiply;
    QCheckBox *cbSort;
    QCheckBox *cbConstrictExpand;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QRadioButton *rbConstrict;
    QRadioButton *rbExpand;
    QCheckBox *cbSetEndTimestamps;
    QCheckBox *cbRemoveEndTimestamps;
    QCheckBox *cbRemoveNames;
    QFrame *line_2;
    QCheckBox *cbApplyToAllTabs;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__ChapterEditor__MassModificationDialog)
    {
        if (mtx__gui__ChapterEditor__MassModificationDialog->objectName().isEmpty())
            mtx__gui__ChapterEditor__MassModificationDialog->setObjectName("mtx__gui__ChapterEditor__MassModificationDialog");
        mtx__gui__ChapterEditor__MassModificationDialog->resize(833, 428);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mtx__gui__ChapterEditor__MassModificationDialog->sizePolicy().hasHeightForWidth());
        mtx__gui__ChapterEditor__MassModificationDialog->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(mtx__gui__ChapterEditor__MassModificationDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        lTitle = new QLabel(mtx__gui__ChapterEditor__MassModificationDialog);
        lTitle->setObjectName("lTitle");
        lTitle->setText(QString::fromUtf8("Text"));
        lTitle->setWordWrap(true);

        verticalLayout_2->addWidget(lTitle);

        line = new QFrame(mtx__gui__ChapterEditor__MassModificationDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        cbShift = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbShift->setObjectName("cbShift");

        gridLayout->addWidget(cbShift, 0, 0, 1, 1);

        dsbMultiplyBy = new QDoubleSpinBox(mtx__gui__ChapterEditor__MassModificationDialog);
        dsbMultiplyBy->setObjectName("dsbMultiplyBy");
        dsbMultiplyBy->setDecimals(9);
        dsbMultiplyBy->setMaximum(9999.999998999999661);
        dsbMultiplyBy->setSingleStep(0.100000000000000);
        dsbMultiplyBy->setValue(1.000000000000000);

        gridLayout->addWidget(dsbMultiplyBy, 1, 1, 1, 1);

        ldwLanguage = new mtx::gui::Util::LanguageDisplayWidget(mtx__gui__ChapterEditor__MassModificationDialog);
        ldwLanguage->setObjectName("ldwLanguage");

        gridLayout->addWidget(ldwLanguage, 2, 1, 1, 1);

        cbSetLanguage = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbSetLanguage->setObjectName("cbSetLanguage");

        gridLayout->addWidget(cbSetLanguage, 2, 0, 1, 1);

        leShiftBy = new QLineEdit(mtx__gui__ChapterEditor__MassModificationDialog);
        leShiftBy->setObjectName("leShiftBy");
        leShiftBy->setText(QString::fromUtf8("00:00:00.000"));
        leShiftBy->setClearButtonEnabled(true);

        gridLayout->addWidget(leShiftBy, 0, 1, 1, 1);

        cbMultiply = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbMultiply->setObjectName("cbMultiply");

        gridLayout->addWidget(cbMultiply, 1, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        cbSort = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbSort->setObjectName("cbSort");

        verticalLayout_2->addWidget(cbSort);

        cbConstrictExpand = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbConstrictExpand->setObjectName("cbConstrictExpand");

        verticalLayout_2->addWidget(cbConstrictExpand);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(24, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        rbConstrict = new QRadioButton(mtx__gui__ChapterEditor__MassModificationDialog);
        rbConstrict->setObjectName("rbConstrict");

        verticalLayout->addWidget(rbConstrict);

        rbExpand = new QRadioButton(mtx__gui__ChapterEditor__MassModificationDialog);
        rbExpand->setObjectName("rbExpand");

        verticalLayout->addWidget(rbExpand);


        horizontalLayout_2->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout_2);

        cbSetEndTimestamps = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbSetEndTimestamps->setObjectName("cbSetEndTimestamps");

        verticalLayout_2->addWidget(cbSetEndTimestamps);

        cbRemoveEndTimestamps = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbRemoveEndTimestamps->setObjectName("cbRemoveEndTimestamps");

        verticalLayout_2->addWidget(cbRemoveEndTimestamps);

        cbRemoveNames = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbRemoveNames->setObjectName("cbRemoveNames");

        verticalLayout_2->addWidget(cbRemoveNames);

        line_2 = new QFrame(mtx__gui__ChapterEditor__MassModificationDialog);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line_2);

        cbApplyToAllTabs = new QCheckBox(mtx__gui__ChapterEditor__MassModificationDialog);
        cbApplyToAllTabs->setObjectName("cbApplyToAllTabs");

        verticalLayout_2->addWidget(cbApplyToAllTabs);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__ChapterEditor__MassModificationDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_2->addWidget(buttonBox);

        QWidget::setTabOrder(cbShift, leShiftBy);
        QWidget::setTabOrder(leShiftBy, cbMultiply);
        QWidget::setTabOrder(cbMultiply, dsbMultiplyBy);
        QWidget::setTabOrder(dsbMultiplyBy, cbSetLanguage);
        QWidget::setTabOrder(cbSetLanguage, ldwLanguage);
        QWidget::setTabOrder(ldwLanguage, cbSort);
        QWidget::setTabOrder(cbSort, cbConstrictExpand);
        QWidget::setTabOrder(cbConstrictExpand, rbConstrict);
        QWidget::setTabOrder(rbConstrict, rbExpand);

        retranslateUi(mtx__gui__ChapterEditor__MassModificationDialog);

        QMetaObject::connectSlotsByName(mtx__gui__ChapterEditor__MassModificationDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__ChapterEditor__MassModificationDialog)
    {
        mtx__gui__ChapterEditor__MassModificationDialog->setWindowTitle(QTR("Chapter mass modification", nullptr));
        cbShift->setText(QTR("S&hift start and end timestamps by the following amount:", nullptr));
        cbSetLanguage->setText(QTR("Set the chapter names' &languages:", nullptr));
        cbMultiply->setText(QTR("&Multiply start and end timestamps by the following factor:", nullptr));
        cbSort->setText(QTR("&Sort chapters by their start and end timestamps", nullptr));
        cbConstrictExpand->setText(QTR("C&onstrict or expand timestamps", nullptr));
        rbConstrict->setText(QTR("&Constrict start and end timestamps of sub-chapters to their parent's start and end timestamps", nullptr));
        rbExpand->setText(QTR("E&xpand chapter's start and end timestamps to include the minimum/maximum timestamps of all their sub-chapters", nullptr));
        cbSetEndTimestamps->setText(QTR("Derive &end timestamps from start timestamps", nullptr));
        cbRemoveEndTimestamps->setText(QTR("&Remove end timestamps", nullptr));
        cbRemoveNames->setText(QTR("Remove &names", nullptr));
        cbApplyToAllTabs->setText(QTR("&Apply modifications in all currently open tabs", nullptr));
    } // retranslateUi

};

} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace ChapterEditor {
namespace Ui {
    class MassModificationDialog: public Ui_MassModificationDialog {};
} // namespace Ui
} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

#endif // MASS_MODIFICATION_DIALOG_H
