/********************************************************************************
** Form generated from reading UI file 'additional_command_line_options_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ADDITIONAL_COMMAND_LINE_OPTIONS_DIALOG_H
#define ADDITIONAL_COMMAND_LINE_OPTIONS_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {
namespace Merge {

class Ui_AdditionalCommandLineOptionsDialog
{
public:
    QVBoxLayout *verticalLayout_5;
    QLabel *lTitle;
    QFrame *lnTitle;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *gbGlobalOutputControl;
    QVBoxLayout *verticalLayout;
    QLabel *lGlobalOutputControl;
    QGridLayout *gridGlobalOutputControl;
    QLabel *label;
    QLabel *label_5;
    QLabel *label_2;
    QFrame *line;
    QFrame *line_5;
    QFrame *line_2;
    QGroupBox *gbDevelopmentHacks;
    QVBoxLayout *verticalLayout_2;
    QLabel *lDevelopmentHacks;
    QGridLayout *gridDevelopmentHacks;
    QLabel *label_3;
    QLabel *label_4;
    QFrame *line_3;
    QFrame *line_4;
    QCheckBox *cbSaveAsDefault;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__Merge__AdditionalCommandLineOptionsDialog)
    {
        if (mtx__gui__Merge__AdditionalCommandLineOptionsDialog->objectName().isEmpty())
            mtx__gui__Merge__AdditionalCommandLineOptionsDialog->setObjectName("mtx__gui__Merge__AdditionalCommandLineOptionsDialog");
        mtx__gui__Merge__AdditionalCommandLineOptionsDialog->resize(950, 530);
        verticalLayout_5 = new QVBoxLayout(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
        verticalLayout_5->setObjectName("verticalLayout_5");
        lTitle = new QLabel(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
        lTitle->setObjectName("lTitle");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lTitle->sizePolicy().hasHeightForWidth());
        lTitle->setSizePolicy(sizePolicy);

        verticalLayout_5->addWidget(lTitle);

        lnTitle = new QFrame(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
        lnTitle->setObjectName("lnTitle");
        lnTitle->setFrameShape(QFrame::Shape::HLine);
        lnTitle->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_5->addWidget(lnTitle);

        scrollArea = new QScrollArea(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShadow(QFrame::Plain);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 930, 415));
        verticalLayout_3 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gbGlobalOutputControl = new QGroupBox(scrollAreaWidgetContents);
        gbGlobalOutputControl->setObjectName("gbGlobalOutputControl");
        verticalLayout = new QVBoxLayout(gbGlobalOutputControl);
        verticalLayout->setObjectName("verticalLayout");
        lGlobalOutputControl = new QLabel(gbGlobalOutputControl);
        lGlobalOutputControl->setObjectName("lGlobalOutputControl");
        lGlobalOutputControl->setWordWrap(true);

        verticalLayout->addWidget(lGlobalOutputControl);

        gridGlobalOutputControl = new QGridLayout();
        gridGlobalOutputControl->setObjectName("gridGlobalOutputControl");
        label = new QLabel(gbGlobalOutputControl);
        label->setObjectName("label");

        gridGlobalOutputControl->addWidget(label, 0, 0, 1, 1);

        label_5 = new QLabel(gbGlobalOutputControl);
        label_5->setObjectName("label_5");

        gridGlobalOutputControl->addWidget(label_5, 0, 1, 1, 1);

        label_2 = new QLabel(gbGlobalOutputControl);
        label_2->setObjectName("label_2");

        gridGlobalOutputControl->addWidget(label_2, 0, 2, 1, 1);

        line = new QFrame(gbGlobalOutputControl);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridGlobalOutputControl->addWidget(line, 1, 0, 1, 1);

        line_5 = new QFrame(gbGlobalOutputControl);
        line_5->setObjectName("line_5");
        line_5->setFrameShape(QFrame::Shape::HLine);
        line_5->setFrameShadow(QFrame::Shadow::Sunken);

        gridGlobalOutputControl->addWidget(line_5, 1, 1, 1, 1);

        line_2 = new QFrame(gbGlobalOutputControl);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridGlobalOutputControl->addWidget(line_2, 1, 2, 1, 1);

        gridGlobalOutputControl->setColumnStretch(1, 1);
        gridGlobalOutputControl->setColumnStretch(2, 4);

        verticalLayout->addLayout(gridGlobalOutputControl);


        verticalLayout_3->addWidget(gbGlobalOutputControl);

        gbDevelopmentHacks = new QGroupBox(scrollAreaWidgetContents);
        gbDevelopmentHacks->setObjectName("gbDevelopmentHacks");
        verticalLayout_2 = new QVBoxLayout(gbDevelopmentHacks);
        verticalLayout_2->setObjectName("verticalLayout_2");
        lDevelopmentHacks = new QLabel(gbDevelopmentHacks);
        lDevelopmentHacks->setObjectName("lDevelopmentHacks");
        lDevelopmentHacks->setWordWrap(true);

        verticalLayout_2->addWidget(lDevelopmentHacks);

        gridDevelopmentHacks = new QGridLayout();
        gridDevelopmentHacks->setObjectName("gridDevelopmentHacks");
        label_3 = new QLabel(gbDevelopmentHacks);
        label_3->setObjectName("label_3");

        gridDevelopmentHacks->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(gbDevelopmentHacks);
        label_4->setObjectName("label_4");

        gridDevelopmentHacks->addWidget(label_4, 0, 1, 1, 1);

        line_3 = new QFrame(gbDevelopmentHacks);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        gridDevelopmentHacks->addWidget(line_3, 1, 0, 1, 1);

        line_4 = new QFrame(gbDevelopmentHacks);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        gridDevelopmentHacks->addWidget(line_4, 1, 1, 1, 1);

        gridDevelopmentHacks->setColumnStretch(1, 1);

        verticalLayout_2->addLayout(gridDevelopmentHacks);


        verticalLayout_3->addWidget(gbDevelopmentHacks);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_5->addWidget(scrollArea);

        cbSaveAsDefault = new QCheckBox(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
        cbSaveAsDefault->setObjectName("cbSaveAsDefault");

        verticalLayout_5->addWidget(cbSaveAsDefault);

        buttonBox = new QDialogButtonBox(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_5->addWidget(buttonBox);


        retranslateUi(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);

        QMetaObject::connectSlotsByName(mtx__gui__Merge__AdditionalCommandLineOptionsDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__Merge__AdditionalCommandLineOptionsDialog)
    {
        mtx__gui__Merge__AdditionalCommandLineOptionsDialog->setWindowTitle(QTR("Additional command line options", nullptr));
        lTitle->setText(QTR("Add additional command line options for mkvmerge", nullptr));
        gbGlobalOutputControl->setTitle(QTR("Global output control", nullptr));
        lGlobalOutputControl->setText(QTR("These are less often used options that control the output structure that mkvmerge creates.", nullptr));
        label->setText(QTR("Option", nullptr));
        label_5->setText(QTR("Value", nullptr));
        label_2->setText(QTR("Description", nullptr));
        gbDevelopmentHacks->setTitle(QTR("Development hacks", nullptr));
        lDevelopmentHacks->setText(QTR("These are options meant for development. They're not officially supported and may change from release to release.", nullptr));
        label_3->setText(QTR("Option", nullptr));
        label_4->setText(QTR("Description", nullptr));
        cbSaveAsDefault->setText(QTR("Save as &default for new multiplex jobs", nullptr));
    } // retranslateUi

};

} // namespace Merge
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Merge {
namespace Ui {
    class AdditionalCommandLineOptionsDialog: public Ui_AdditionalCommandLineOptionsDialog {};
} // namespace Ui
} // namespace Merge
} // namespace gui
} // namespace mtx

#endif // ADDITIONAL_COMMAND_LINE_OPTIONS_DIALOG_H
