/********************************************************************************
** Form generated from reading UI file 'attachments_page.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef ATTACHMENTS_PAGE_H
#define ATTACHMENTS_PAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace mtx {
namespace gui {
namespace HeaderEditor {

class Ui_AttachmentsPage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *heading;
    QFrame *line;
    QSpacerItem *verticalSpacer;
    QLabel *instructions;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *addAttachments;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *mtx__gui__HeaderEditor__AttachmentsPage)
    {
        if (mtx__gui__HeaderEditor__AttachmentsPage->objectName().isEmpty())
            mtx__gui__HeaderEditor__AttachmentsPage->setObjectName("mtx__gui__HeaderEditor__AttachmentsPage");
        mtx__gui__HeaderEditor__AttachmentsPage->resize(457, 472);
        mtx__gui__HeaderEditor__AttachmentsPage->setAcceptDrops(true);
        mtx__gui__HeaderEditor__AttachmentsPage->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(mtx__gui__HeaderEditor__AttachmentsPage);
        verticalLayout->setObjectName("verticalLayout");
        heading = new QLabel(mtx__gui__HeaderEditor__AttachmentsPage);
        heading->setObjectName("heading");

        verticalLayout->addWidget(heading);

        line = new QFrame(mtx__gui__HeaderEditor__AttachmentsPage);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        verticalSpacer = new QSpacerItem(20, 136, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        instructions = new QLabel(mtx__gui__HeaderEditor__AttachmentsPage);
        instructions->setObjectName("instructions");
        instructions->setWordWrap(true);

        verticalLayout->addWidget(instructions);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        addAttachments = new QPushButton(mtx__gui__HeaderEditor__AttachmentsPage);
        addAttachments->setObjectName("addAttachments");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addAttachments->setIcon(icon);

        horizontalLayout_2->addWidget(addAttachments);

        horizontalSpacer_4 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 135, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);


        retranslateUi(mtx__gui__HeaderEditor__AttachmentsPage);

        QMetaObject::connectSlotsByName(mtx__gui__HeaderEditor__AttachmentsPage);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__HeaderEditor__AttachmentsPage)
    {
        heading->setText(QTR("Attachments", nullptr));
        instructions->setText(QTR("You can add attachments by clicking on the button below, by right-clicking on a node in the tree and selecting \"Add attachments\" from the popup menu or by dragging & dropping files here or onto the tree.", nullptr));
        addAttachments->setText(QTR("&Add attachments", nullptr));
        (void)mtx__gui__HeaderEditor__AttachmentsPage;
    } // retranslateUi

};

} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace HeaderEditor {
namespace Ui {
    class AttachmentsPage: public Ui_AttachmentsPage {};
} // namespace Ui
} // namespace HeaderEditor
} // namespace gui
} // namespace mtx

#endif // ATTACHMENTS_PAGE_H
