/********************************************************************************
** Form generated from reading UI file 'tab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef TAB_H
#define TAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "mkvtoolnix-gui/util/basic_tree_view.h"
#include "mkvtoolnix-gui/util/elide_label.h"

namespace mtx {
namespace gui {
namespace Info {

class Ui_Tab
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout;
    QLabel *fileNameLabel;
    mtx::gui::Util::ElideLabel *fileName;
    QLabel *sizeLabel;
    QLabel *size;
    QLabel *directoryLabel;
    mtx::gui::Util::ElideLabel *directory;
    QLabel *modifiedLabel;
    QLabel *modified;
    QSpacerItem *horizontalSpacer;
    QFrame *line;
    mtx::gui::Util::BasicTreeView *elements;

    void setupUi(QWidget *mtx__gui__Info__Tab)
    {
        if (mtx__gui__Info__Tab->objectName().isEmpty())
            mtx__gui__Info__Tab->setObjectName("mtx__gui__Info__Tab");
        mtx__gui__Info__Tab->resize(400, 300);
        mtx__gui__Info__Tab->setWindowTitle(QString::fromUtf8("mtx::gui::Info::Tab"));
        verticalLayout = new QVBoxLayout(mtx__gui__Info__Tab);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        fileNameLabel = new QLabel(mtx__gui__Info__Tab);
        fileNameLabel->setObjectName("fileNameLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fileNameLabel->sizePolicy().hasHeightForWidth());
        fileNameLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fileNameLabel, 0, 0, 1, 1);

        fileName = new mtx::gui::Util::ElideLabel(mtx__gui__Info__Tab);
        fileName->setObjectName("fileName");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(fileName->sizePolicy().hasHeightForWidth());
        fileName->setSizePolicy(sizePolicy1);
        fileName->setText(QString::fromUtf8("fn"));

        gridLayout->addWidget(fileName, 0, 1, 1, 1);

        sizeLabel = new QLabel(mtx__gui__Info__Tab);
        sizeLabel->setObjectName("sizeLabel");

        gridLayout->addWidget(sizeLabel, 0, 2, 1, 1);

        size = new QLabel(mtx__gui__Info__Tab);
        size->setObjectName("size");
        size->setText(QString::fromUtf8("size"));
        size->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(size, 0, 3, 1, 1);

        directoryLabel = new QLabel(mtx__gui__Info__Tab);
        directoryLabel->setObjectName("directoryLabel");
        sizePolicy.setHeightForWidth(directoryLabel->sizePolicy().hasHeightForWidth());
        directoryLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(directoryLabel, 1, 0, 1, 1);

        directory = new mtx::gui::Util::ElideLabel(mtx__gui__Info__Tab);
        directory->setObjectName("directory");
        sizePolicy1.setHeightForWidth(directory->sizePolicy().hasHeightForWidth());
        directory->setSizePolicy(sizePolicy1);
        directory->setText(QString::fromUtf8("dir"));

        gridLayout->addWidget(directory, 1, 1, 1, 1);

        modifiedLabel = new QLabel(mtx__gui__Info__Tab);
        modifiedLabel->setObjectName("modifiedLabel");

        gridLayout->addWidget(modifiedLabel, 1, 2, 1, 1);

        modified = new QLabel(mtx__gui__Info__Tab);
        modified->setObjectName("modified");
        modified->setText(QString::fromUtf8("mod"));
        modified->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(modified, 1, 3, 1, 1);


        horizontalLayout->addLayout(gridLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        line = new QFrame(mtx__gui__Info__Tab);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        elements = new mtx::gui::Util::BasicTreeView(mtx__gui__Info__Tab);
        elements->setObjectName("elements");
        elements->setContextMenuPolicy(Qt::CustomContextMenu);
        elements->setEditTriggers(QAbstractItemView::NoEditTriggers);
        elements->setAlternatingRowColors(false);

        verticalLayout->addWidget(elements);


        retranslateUi(mtx__gui__Info__Tab);

        QMetaObject::connectSlotsByName(mtx__gui__Info__Tab);
    } // setupUi

    void retranslateUi(QWidget *mtx__gui__Info__Tab)
    {
        fileNameLabel->setText(QTR("File name:", nullptr));
        sizeLabel->setText(QTR("Size:", nullptr));
        directoryLabel->setText(QTR("Directory:", nullptr));
        modifiedLabel->setText(QTR("Modified:", nullptr));
        (void)mtx__gui__Info__Tab;
    } // retranslateUi

};

} // namespace Info
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace Info {
namespace Ui {
    class Tab: public Ui_Tab {};
} // namespace Ui
} // namespace Info
} // namespace gui
} // namespace mtx

#endif // TAB_H
