/********************************************************************************
** Form generated from reading UI file 'generate_sub_chapters_parameters_dialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef GENERATE_SUB_CHAPTERS_PARAMETERS_DIALOG_H
#define GENERATE_SUB_CHAPTERS_PARAMETERS_DIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "mkvtoolnix-gui/util/basic_spin_box.h"
#include "mkvtoolnix-gui/util/language_display_widget.h"

namespace mtx {
namespace gui {
namespace ChapterEditor {

class Ui_GenerateSubChaptersParametersDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QFrame *line;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QLabel *label_5;
    QLineEdit *leNameTemplate;
    mtx::gui::Util::BasicSpinBox *sbFirstChapterNumber;
    QLabel *lLanguage;
    QLabel *label_6;
    mtx::gui::Util::LanguageDisplayWidget *ldwLanguage;
    QLineEdit *leStartTimestamp;
    mtx::gui::Util::BasicSpinBox *sbNumberOfEntries;
    QLabel *label_2;
    mtx::gui::Util::BasicSpinBox *sbDuration;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog)
    {
        if (mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog->objectName().isEmpty())
            mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog->setObjectName("mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog");
        mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog->resize(453, 274);
        verticalLayout = new QVBoxLayout(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        line = new QFrame(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        label_5 = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        leNameTemplate = new QLineEdit(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        leNameTemplate->setObjectName("leNameTemplate");
        leNameTemplate->setClearButtonEnabled(true);

        gridLayout->addWidget(leNameTemplate, 4, 1, 1, 1);

        sbFirstChapterNumber = new mtx::gui::Util::BasicSpinBox(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        sbFirstChapterNumber->setObjectName("sbFirstChapterNumber");
        sbFirstChapterNumber->setMinimum(1);
        sbFirstChapterNumber->setMaximum(999999);

        gridLayout->addWidget(sbFirstChapterNumber, 2, 1, 1, 1);

        lLanguage = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        lLanguage->setObjectName("lLanguage");

        gridLayout->addWidget(lLanguage, 5, 0, 1, 1);

        label_6 = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 3, 0, 1, 1);

        ldwLanguage = new mtx::gui::Util::LanguageDisplayWidget(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        ldwLanguage->setObjectName("ldwLanguage");

        gridLayout->addWidget(ldwLanguage, 5, 1, 1, 1);

        leStartTimestamp = new QLineEdit(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        leStartTimestamp->setObjectName("leStartTimestamp");
        leStartTimestamp->setClearButtonEnabled(true);

        gridLayout->addWidget(leStartTimestamp, 3, 1, 1, 1);

        sbNumberOfEntries = new mtx::gui::Util::BasicSpinBox(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        sbNumberOfEntries->setObjectName("sbNumberOfEntries");
        sbNumberOfEntries->setMinimum(1);
        sbNumberOfEntries->setMaximum(9999);
        sbNumberOfEntries->setValue(10);

        gridLayout->addWidget(sbNumberOfEntries, 0, 1, 1, 1);

        label_2 = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 4, 0, 1, 1);

        sbDuration = new mtx::gui::Util::BasicSpinBox(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        sbDuration->setObjectName("sbDuration");
        sbDuration->setMaximum(999999);
        sbDuration->setSingleStep(10);
        sbDuration->setValue(300);

        gridLayout->addWidget(sbDuration, 1, 1, 1, 1);

        label_4 = new QLabel(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 1, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(sbNumberOfEntries);
        label_5->setBuddy(sbFirstChapterNumber);
        lLanguage->setBuddy(ldwLanguage);
        label_6->setBuddy(leStartTimestamp);
        label_2->setBuddy(leNameTemplate);
        label_4->setBuddy(sbDuration);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(sbNumberOfEntries, sbDuration);
        QWidget::setTabOrder(sbDuration, sbFirstChapterNumber);
        QWidget::setTabOrder(sbFirstChapterNumber, leStartTimestamp);
        QWidget::setTabOrder(leStartTimestamp, leNameTemplate);
        QWidget::setTabOrder(leNameTemplate, ldwLanguage);

        retranslateUi(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);

        QMetaObject::connectSlotsByName(mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog);
    } // setupUi

    void retranslateUi(QDialog *mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog)
    {
        mtx__gui__ChapterEditor__GenerateSubChaptersParametersDialog->setWindowTitle(QTR("Generate sub-chapters", nullptr));
        label->setText(QTR("Generating a number of chapters spaced evenly apart", nullptr));
        label_3->setText(QTR("Nu&mber of entries to create:", nullptr));
        label_5->setText(QTR("Chapter &number of first created entry:", nullptr));
        lLanguage->setText(QTR("&Language:", nullptr));
        label_6->setText(QTR("&Start timestamp of first created entry:", nullptr));
        label_2->setText(QTR("Name tem&plate:", nullptr));
        sbDuration->setSuffix(QString());
        label_4->setText(QTR("&Duration of each entry in seconds:", nullptr));
    } // retranslateUi

};

} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

namespace mtx {
namespace gui {
namespace ChapterEditor {
namespace Ui {
    class GenerateSubChaptersParametersDialog: public Ui_GenerateSubChaptersParametersDialog {};
} // namespace Ui
} // namespace ChapterEditor
} // namespace gui
} // namespace mtx

#endif // GENERATE_SUB_CHAPTERS_PARAMETERS_DIALOG_H
